
#                                  scala.App                                  #

```
trait App extends DelayedInit
```

The `App` trait can be used to quickly turn objects into executable programs.
Here is an example:

```scala
object Main extends App {
  Console.println("Hello World: " + (args mkString ", "))
}
```

Here, object `Main` inherits the `main` method of `App` .

 `args` returns the current command line arguments as an array.

### Caveats

 * _It should be noted that this trait is implemented using the DelayedInit
functionality, which means that fields of the object will not have been
initialized before the main method has been executed._*

It should also be noted that the `main` method should not be overridden: the
whole class body becomes the “main method”.

Future versions of this trait will no longer extend `DelayedInit` .

* Source
  * [App.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/App.scala#L1)
* Version
  * 2.1, 15/02/2011


--------------------------------------------------------------------------------
                    Deprecated Value Members From scala.App
--------------------------------------------------------------------------------


### `def delayedInit(body: ⇒ Unit): Unit`                                    ###

The init hook. This saves all initialization code for execution within `main` .
This method is normally never called directly from user code. Instead it is
called as compiler-generated code for those classes and objects (but not traits)
that inherit from the `DelayedInit` trait and that do not themselves define a
 `delayedInit` method.

* body
  * the initialization code to be stored for later execution

* Definition Classes
  * App → DelayedInit
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ The delayedInit mechanism will disappear.

(defined at scala.App)


--------------------------------------------------------------------------------
                          Value Members From scala.App
--------------------------------------------------------------------------------


### `def args: Array[String]`                                                ###

The command line arguments passed to the application's `main` method.

* Attributes
  * protected
* Annotations
  * @deprecatedOverriding ("args should not be overridden", "2.11.0")

(defined at scala.App)


### `val executionStart: Long`                                               ###

The time when the execution of this program started, in milliseconds since 1
January 1970 UTC.

(defined at scala.App)


### `def main(args: Array[String]): Unit`                                    ###

The main method. This stores all arguments so that they can be retrieved with
 `args` and then executes all initialization code segments in the order in which
they were passed to `delayedInit` .

* args
  * the arguments passed to the main method

* Annotations
  * @deprecatedOverriding ("main should not be overridden", "2.11.0")
(defined at scala.App)
