
#                                scala.Console                                #

```
object Console extends DeprecatedConsole with AnsiColor
```

Implements functionality for printing Scala values on the terminal as well as
reading specific values. Also defines constants for marking up text on ANSI
terminals.

* Source
  * [Console.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Console.scala#L1)
* Version
  * 1.0, 03/09/2003


--------------------------------------------------------------------------------
                        Value Members From scala.Console
--------------------------------------------------------------------------------


### `def err: PrintStream`                                                   ###

The default error, can be overridden by `setErr`

(defined at scala.Console)


### `def flush(): Unit`                                                      ###

Flushes the output stream. This function is required when partial output (i.e.
output not terminated by a newline character) has to be made visible on the
terminal.

(defined at scala.Console)


### `def in: BufferedReader`                                                 ###

The default input, can be overridden by `setIn`

(defined at scala.Console)


### `def out: PrintStream`                                                   ###

The default output, can be overridden by `setOut`

(defined at scala.Console)


### `def print(obj: Any): Unit`                                              ###

Prints an object to `out` using its `toString` method.

* obj
  * the object to print; may be null.

(defined at scala.Console)


### `def printf(text: String, args: Any*): Unit`                             ###

Prints its arguments as a formatted string to the default output, based on a
string pattern (in a fashion similar to printf in C).

The interpretation of the formatting patterns is described in
`java.util.Formatter`.

* text
  * the pattern for formatting the arguments.
* args
  * the arguments used to instantiating the pattern.

* Exceptions thrown
  * `java.lang.IllegalArgumentException` if there was a problem with the format
    string or arguments

(defined at scala.Console)


### `def println(): Unit`                                                    ###

Prints a newline character on the default output.

(defined at scala.Console)


### `def println(x: Any): Unit`                                              ###

Prints out an object to the default output, followed by a newline character.

* x
  * the object to print.

(defined at scala.Console)


### `def setErrDirect(err: PrintStream): Unit`                               ###

* Attributes
  * protected
* Definition Classes
  * Console → DeprecatedConsole

(defined at scala.Console)


### `def setInDirect(in: BufferedReader): Unit`                              ###

* Attributes
  * protected
* Definition Classes
  * Console → DeprecatedConsole

(defined at scala.Console)


### `def setOutDirect(out: PrintStream): Unit`                               ###

Internal usage only.

* Attributes
  * protected
* Definition Classes
  * Console → DeprecatedConsole

(defined at scala.Console)


### `def withErr[T](err: OutputStream)(thunk: ⇒ T): T`                       ###

Sets the default error stream for the duration of execution of one thunk.

* err
  * the new error stream.
* thunk
  * the code to execute with the new error stream active
* returns
  * the results of `thunk`

* See also
  * `withErr[T](err:PrintStream)(thunk: =>T)`

(defined at scala.Console)


### `def withErr[T](err: PrintStream)(thunk: ⇒ T): T`                        ###

Set the default error stream for the duration of execution of one thunk.

* err
  * the new error stream.
* thunk
  * the code to execute with the new error stream active
* returns
  * the results of `thunk`

* See also
  * `withErr[T](err:OutputStream)(thunk: =>T)`

Example:

```scala
withErr(Console.out) { println("This goes to default _out_") }
```

(defined at scala.Console)


### `def withIn[T](in: InputStream)(thunk: ⇒ T): T`                          ###

Sets the default input stream for the duration of execution of one thunk.

* in
  * the new input stream.
* thunk
  * the code to execute with the new input stream active
* returns
  * the results of `thunk`

* See also
  * `withIn[T](reader:Reader)(thunk: =>T)`

(defined at scala.Console)


### `def withIn[T](reader: Reader)(thunk: ⇒ T): T`                           ###

Sets the default input stream for the duration of execution of one thunk.

* thunk
  * the code to execute with the new input stream active
* returns
  * the results of `thunk`

* See also
  * `withIn[T](in:InputStream)(thunk: =>T)`

Example:

```scala
val someFile:Reader = openFile("file.txt")
withIn(someFile) {
  // Reads a line from file.txt instead of default input
  println(readLine)
}
```

(defined at scala.Console)


### `def withOut[T](out: OutputStream)(thunk: ⇒ T): T`                       ###

Sets the default output stream for the duration of execution of one thunk.

* out
  * the new output stream.
* thunk
  * the code to execute with the new output stream active
* returns
  * the results of `thunk`

* See also
  * `withOut[T](out:PrintStream)(thunk: => T)`

(defined at scala.Console)


### `def withOut[T](out: PrintStream)(thunk: ⇒ T): T`                        ###

Sets the default output stream for the duration of execution of one thunk.

* out
  * the new output stream.
* thunk
  * the code to execute with the new output stream active
* returns
  * the results of `thunk`

* See also
  * `withOut[T](out:OutputStream)(thunk: => T)`

Example:

```scala
withOut(Console.err) { println("This goes to default _error_") }
```

(defined at scala.Console)


--------------------------------------------------------------------------------
             Deprecated Value Members From scala.DeprecatedConsole
--------------------------------------------------------------------------------


### `def readBoolean(): Boolean`                                             ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readByte(): Byte`                                                   ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readChar(): Char`                                                   ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readDouble(): Double`                                               ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readFloat(): Float`                                                 ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readInt(): Int`                                                     ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readLine(): String`                                                 ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readLine(text: String, args: Any*): String`                         ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readLong(): Long`                                                   ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readShort(): Short`                                                 ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readf(format: String): List[Any]`                                   ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readf1(format: String): Any`                                        ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readf2(format: String): (Any, Any)`                                 ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def readf3(format: String): (Any, Any, Any)`                            ###

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use the method in scala.io.StdIn

(defined at scala.DeprecatedConsole)


### `def setErr(err: OutputStream): Unit`                                    ###

Sets the default error stream.

* err
  * the new error stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withErr

(defined at scala.DeprecatedConsole)


### `def setErr(err: PrintStream): Unit`                                     ###

Sets the default error stream.

* err
  * the new error stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withErr

(defined at scala.DeprecatedConsole)


### `def setIn(in: InputStream): Unit`                                       ###

Sets the default input stream.

* in
  * the new input stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withIn

(defined at scala.DeprecatedConsole)


### `def setIn(reader: Reader): Unit`                                        ###

Sets the default input stream.

* reader
  * specifies the new input stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withIn

(defined at scala.DeprecatedConsole)


### `def setOut(out: OutputStream): Unit`                                    ###

Sets the default output stream.

* out
  * the new output stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withOut

(defined at scala.DeprecatedConsole)


### `def setOut(out: PrintStream): Unit`                                     ###

Sets the default output stream.

* out
  * the new output stream.

* Definition Classes
  * DeprecatedConsole
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use withOut

(defined at scala.DeprecatedConsole)


--------------------------------------------------------------------------------
                     Value Members From scala.io.AnsiColor
--------------------------------------------------------------------------------


### `final val BLACK: String("\033[30m")`                                    ###

Foreground color for ANSI black

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val BLACK_B: String("\033[40m")`                                  ###

Background color for ANSI black

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val BLINK: String("\033[5m")`                                     ###

ANSI blink

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val BLUE: String("\033[34m")`                                     ###

Foreground color for ANSI blue

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val BLUE_B: String("\033[44m")`                                   ###

Background color for ANSI blue

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val BOLD: String("\033[1m")`                                      ###

ANSI bold

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val CYAN: String("\033[36m")`                                     ###

Foreground color for ANSI cyan

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val CYAN_B: String("\033[46m")`                                   ###

Background color for ANSI cyan

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val GREEN: String("\033[32m")`                                    ###

Foreground color for ANSI green

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val GREEN_B: String("\033[42m")`                                  ###

Background color for ANSI green

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val INVISIBLE: String("\033[8m")`                                 ###

ANSI invisible

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val MAGENTA: String("\033[35m")`                                  ###

Foreground color for ANSI magenta

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val MAGENTA_B: String("\033[45m")`                                ###

Background color for ANSI magenta

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val RED: String("\033[31m")`                                      ###

Foreground color for ANSI red

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val RED_B: String("\033[41m")`                                    ###

Background color for ANSI red

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val RESET: String("\033[0m")`                                     ###

Reset ANSI styles

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val REVERSED: String("\033[7m")`                                  ###

ANSI reversed

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val UNDERLINED: String("\033[4m")`                                ###

ANSI underlines

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val WHITE: String("\033[37m")`                                    ###

Foreground color for ANSI white

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val WHITE_B: String("\033[47m")`                                  ###

Background color for ANSI white

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val YELLOW: String("\033[33m")`                                   ###

Foreground color for ANSI yellow

* Definition Classes
  * AnsiColor

(defined at scala.io.AnsiColor)


### `final val YELLOW_B: String("\033[43m")`                                 ###

Background color for ANSI yellow

* Definition Classes
  * AnsiColor
(defined at scala.io.AnsiColor)
