
#                                scala.Dynamic                                #

```
trait Dynamic extends Any
```

A marker trait that enables dynamic invocations. Instances `x` of this trait
allow method invocations `x.meth(args)` for arbitrary method names `meth` and
argument lists `args` as well as field accesses `x.field` for arbitrary field
names `field` .

If a call is not natively supported by `x` (i.e. if type checking fails), it is
rewritten according to the following rules:

```scala
foo.method("blah")      ~~> foo.applyDynamic("method")("blah")
foo.method(x = "blah")  ~~> foo.applyDynamicNamed("method")(("x", "blah"))
foo.method(x = 1, 2)    ~~> foo.applyDynamicNamed("method")(("x", 1), ("", 2))
foo.field           ~~> foo.selectDynamic("field")
foo.varia = 10      ~~> foo.updateDynamic("varia")(10)
foo.arr(10) = 13    ~~> foo.selectDynamic("arr").update(10, 13)
foo.arr(10)         ~~> foo.applyDynamic("arr")(10)
```

As of Scala 2.10, defining direct or indirect subclasses of this trait is only
possible if the language feature `dynamics` is enabled.

* Source
  * [Dynamic.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Dynamic.scala#L1)


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any
(defined at scala.Any###)
