
#                               scala.Function0                               #

```
trait Function0[+R] extends AnyRef
```

A function of 0 parameters.

In the following example, the definition of javaVersion is a shorthand for the
anonymous class definition anonfun0:

```scala
object Main extends App {
   val javaVersion = () => sys.props("java.version")

   val anonfun0 = new Function0[String] {
     def apply(): String = sys.props("java.version")
   }
   assert(javaVersion() == anonfun0())
}
```

Note that `Function1` does not define a total function, as might be suggested by
the existence of scala.PartialFunction. The only distinction between
 `Function1` and `PartialFunction` is that the latter can specify inputs which
it will not handle.

* Self Type
  * () ⇒ R
* Source
  * [Function0.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Function0.scala#L1)


--------------------------------------------------------------------------------
                  Abstract Value Members From scala.Function0
--------------------------------------------------------------------------------


### `abstract def apply(): R`                                                ###

Apply the body of this function to the arguments.

* returns
  * the result of function application.

(defined at scala.Function0)


--------------------------------------------------------------------------------
                  Concrete Value Members From scala.Function0
--------------------------------------------------------------------------------


### `def toString(): String`                                                 ###

Creates a String representation of this object. The default representation is
platform dependent. On the java platform it is the concatenation of the class
name, "@", and the object's hashcode in hexadecimal.

* returns
  * a String representation of the object.

* Definition Classes
  * Function0 → AnyRef → Any
(defined at scala.Function0)
