
#                                scala.Product                                #

```
trait Product extends Equals
```

Base trait for all products, which in the standard library include at least
scala.Product1 through scala.Product22 and therefore also their subclasses
scala.Tuple1 through scala.Tuple22. In addition, all case classes implement
 `Product` with synthetically generated methods.

* Source
  * [Product.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Product.scala#L1)
* Version
  * 1.0
* Since
  * 2.3


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                    Abstract Value Members From scala.Equals
--------------------------------------------------------------------------------


### `abstract def canEqual(that: Any): Boolean`                              ###

A method that should be called from every well-designed equals method that is
open to be overridden in a subclass. See Programming in Scala, Chapter 28 for
discussion and design.

* that
  * the value being probed for possible equality
* returns
  * true if this instance can possibly equal `that` , otherwise false

* Definition Classes
  * Equals

(defined at scala.Equals)


--------------------------------------------------------------------------------
                   Abstract Value Members From scala.Product
--------------------------------------------------------------------------------


### `abstract def productArity: Int`                                         ###

The size of this product.

* returns
  * for a product `A(x1, ..., xk)` , returns `k`

(defined at scala.Product)


### `abstract def productElement(n: Int): Any`                               ###

The n <sup>th</sup> element of this product, 0-based. In other words, for a
product `A(x1, ..., xk)` , returns `x(n+1)` where `0 < n < k` .

* n
  * the index of the element to return
* returns
  * the element `n` elements after the first element

* Exceptions thrown
  *

(defined at scala.Product)


--------------------------------------------------------------------------------
                   Concrete Value Members From scala.Product
--------------------------------------------------------------------------------


### `def productIterator: Iterator[Any]`                                     ###

An iterator over all the elements of this product.

* returns
  * in the default implementation, an `Iterator[Any]`

(defined at scala.Product)


### `def productPrefix: String`                                              ###

A string used in the `toString` methods of derived classes. Implementations may
override this method to prepend a string prefix to the result of `toString`
methods.

* returns
  * in the default implementation, the empty string
(defined at scala.Product)
