
#                                scala.Product4                                #

```
trait Product4[+T1, +T2, +T3, +T4] extends Product
```

Product4 is a cartesian product of 4 components.

* Source
  * [Product4.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Product4.scala#L1)
* Since
  * 2.3


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                    Abstract Value Members From scala.Equals
--------------------------------------------------------------------------------


### `abstract def canEqual(that: Any): Boolean`                              ###

A method that should be called from every well-designed equals method that is
open to be overridden in a subclass. See Programming in Scala, Chapter 28 for
discussion and design.

* that
  * the value being probed for possible equality
* returns
  * true if this instance can possibly equal `that` , otherwise false

* Definition Classes
  * Equals

(defined at scala.Equals)


--------------------------------------------------------------------------------
                   Concrete Value Members From scala.Product
--------------------------------------------------------------------------------


### `def productIterator: Iterator[Any]`                                     ###

An iterator over all the elements of this product.

* returns
  * in the default implementation, an `Iterator[Any]`

* Definition Classes
  * Product

(defined at scala.Product)


### `def productPrefix: String`                                              ###

A string used in the `toString` methods of derived classes. Implementations may
override this method to prepend a string prefix to the result of `toString`
methods.

* returns
  * in the default implementation, the empty string

* Definition Classes
  * Product

(defined at scala.Product)


--------------------------------------------------------------------------------
                   Abstract Value Members From scala.Product4
--------------------------------------------------------------------------------


### `abstract def _1: T1`                                                    ###

A projection of element 1 of this Product.

* returns
  * A projection of element 1.

(defined at scala.Product4)


### `abstract def _2: T2`                                                    ###

A projection of element 2 of this Product.

* returns
  * A projection of element 2.

(defined at scala.Product4)


### `abstract def _3: T3`                                                    ###

A projection of element 3 of this Product.

* returns
  * A projection of element 3.

(defined at scala.Product4)


### `abstract def _4: T4`                                                    ###

A projection of element 4 of this Product.

* returns
  * A projection of element 4.

(defined at scala.Product4)


--------------------------------------------------------------------------------
                   Concrete Value Members From scala.Product4
--------------------------------------------------------------------------------


### `def productArity: Int`                                                  ###

The arity of this product.

* returns
  * 4

* Definition Classes
  * Product4 → Product

(defined at scala.Product4)


### `def productElement(n: Int): Any`                                        ###

Returns the n-th projection of this product if 0 < n <= productArity, otherwise
throws an `IndexOutOfBoundsException` .

* n
  * number of the projection to be returned
* returns
  * same as `._(n+1)` , for example `productElement(0)` is the same as `._1` .

* Definition Classes
  * Product4 → Product
* Annotations
  * @ throws (clazz = classOf[IndexOutOfBoundsException])
* Exceptions thrown
  * IndexOutOfBoundsException
(defined at scala.Product4)
