
#                                 scala.Proxy                                 #

```
trait Proxy extends Any
```

This class implements a simple proxy that forwards all calls to the public,
non-final methods defined in class `Any` to another object self. Those methods
are:

```scala
def hashCode(): Int
def equals(other: Any): Boolean
def toString(): String
```

 *Note:* forwarding methods in this way will most likely create an asymmetric
equals method, which is not generally recommended.

* Source
  * [Proxy.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/Proxy.scala#L1)
* Version
  * 1.0, 26/04/2004


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                    Abstract Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `abstract def self: Any`                                                 ###

(defined at scala.Proxy)


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def equals(that: Any): Boolean`                                         ###

Compares the receiver object ( `this` ) with the argument object ( `that` ) for
equivalence.

Any implementation of this method should be an
[equivalence relation](http://en.wikipedia.org/wiki/Equivalence_relation) :

* It is reflexive: for any instance `x` of type `Any` , `x.equals(x)` should
   return `true` .
* It is symmetric: for any instances `x` and `y` of type `Any` , `x.equals(y)`
   should return `true` if and only if `y.equals(x)` returns `true` .
* It is transitive: for any instances `x` , `y` , and `z` of type `AnyRef` if
    `x.equals(y)` returns `true` and `y.equals(z)` returns `true` , then
    `x.equals(z)` should return `true` .

If you override this method, you should verify that your implementation remains
an equivalence relation. Additionally, when overriding this method it is usually
necessary to override `hashCode` to ensure that objects which are "equal" (
 `o1.equals(o2)` returns `true` ) hash to the same scala.Int. (
 `o1.hashCode.equals(o2.hashCode)` ).

* that
  * the object to compare against this object for equality.
* returns
  * `true` if the receiver object is equivalent to the argument; `false`
    otherwise.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def hashCode(): Int`                                                    ###

Calculate a hash code value for the object.

The default hashing algorithm is platform dependent.

Note that it is allowed for two objects to have identical hash codes (
 `o1.hashCode.equals(o2.hashCode)` ) yet not be equal ( `o1.equals(o2)` returns
 `false` ). A degenerate implementation could always return `0` . However, it is
required that if two objects are equal ( `o1.equals(o2)` returns `true` ) that
they have identical hash codes ( `o1.hashCode.equals(o2.hashCode)` ). Therefore,
when overriding this method, be sure to verify that the behavior is consistent
with the `equals` method.

* returns
  * the hash code value for this object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any
(defined at scala.Proxy)
