
#                        scala.collection.MapProxyLike                        #

```
trait MapProxyLike[A, +B, +This <: MapLike[A, B, This] with Map[A, B]] extends MapLike[A, B, This] with IterableProxyLike[(A, B), This]
```

This trait implements a proxy for Map objects. It forwards all calls to a
different Map object.

* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Proxying is deprecated due to lack of use and
    compiler-level support.
* Source
  * [MapProxyLike.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/collection/MapProxyLike.scala#L1)
* Version
  * 2.8
* Since
  * 2.8


--------------------------------------------------------------------------------
                                  Type Members
--------------------------------------------------------------------------------


### `class DefaultKeySet extends AbstractSet[A] with Set[A] with Serializable` ###

The implementation class of the set returned by `keySet` .

* Attributes
  * protected
* Definition Classes
  * MapLike


### `class DefaultValuesIterable extends AbstractIterable[B] with Iterable[B] with Serializable` ###

The implementation class of the iterable returned by `values` .

* Attributes
  * protected
* Definition Classes
  * MapLike


### `class FilteredKeys extends AbstractMap[A, B] with DefaultMap[A, B]`     ###

* Attributes
  * protected
* Definition Classes
  * MapLike


### `class MappedValues[C] extends AbstractMap[A, C] with DefaultMap[A, C]`  ###

* Attributes
  * protected
* Definition Classes
  * MapLike


### `type Self = This`                                                       ###

The type implementing this traversable

* Attributes
  * protected[this]
* Definition Classes
  * TraversableLike


### `class WithFilter extends FilterMonadic[A, Repr]`                        ###

A class supporting filtered operations. Instances of this class are returned by
method `withFilter` .

* Definition Classes
  * TraversableLike


--------------------------------------------------------------------------------
                  Concrete Value Members From scala.Function1
--------------------------------------------------------------------------------


### `def compose[A](g: (A) ⇒ A): (A) ⇒ B`                                    ###

Composes two instances of Function1 in a new Function1, with this function
applied last.

* A
  * the type to which function `g` can be applied
* g
  * a function A => T1
* returns
  * a new function `f` such that `f(x) == apply(g(x))`

* Definition Classes
  * Function1
* Annotations
  * @ unspecialized ()

(defined at scala.Function1)


--------------------------------------------------------------------------------
               Concrete Value Members From scala.PartialFunction
--------------------------------------------------------------------------------


### `def andThen[C](k: (B) ⇒ C): PartialFunction[A, C]`                      ###

Composes this partial function with a transformation function that gets applied
to results of this partial function.

* C
  * the result type of the transformation function.
* k
  * the transformation function
* returns
  * a partial function with the same domain as this partial function, which maps
    arguments `x` to `k(this(x))` .

* Definition Classes
  * PartialFunction → Function1

(defined at scala.PartialFunction)


### `def applyOrElse[A1 <: A, B1 >: B](x: A1, default: (A1) ⇒ B1): B1`       ###

Applies this partial function to the given argument when it is contained in the
function domain. Applies fallback function where this partial function is not
defined.

Note that expression `pf.applyOrElse(x, default)` is equivalent to

```scala
if(pf isDefinedAt x) pf(x) else default(x)
```

except that `applyOrElse` method can be implemented more efficiently. For all
partial function literals the compiler generates an `applyOrElse` implementation
which avoids double evaluation of pattern matchers and guards. This makes
 `applyOrElse` the basis for the efficient implementation for many operations
and scenarios, such as:

* combining partial functions into `orElse` / `andThen` chains does not lead to
   excessive `apply` / `isDefinedAt` evaluation
*  `lift` and `unlift` do not evaluate source functions twice on each invocation
*  `runWith` allows efficient imperative-style combining of partial functions
   with conditionally applied actions

For non-literal partial function classes with nontrivial `isDefinedAt` method it
is recommended to override `applyOrElse` with custom implementation that avoids
double `isDefinedAt` evaluation. This may result in better performance and more
predictable behavior w.r.t. side effects.

* x
  * the function argument
* default
  * the fallback function
* returns
  * the result of this function or fallback function application.

* Definition Classes
  * PartialFunction
* Since
  * 2.10

(defined at scala.PartialFunction)


### `def lift: (A) ⇒ Option[B]`                                              ###

Turns this partial function into a plain function returning an `Option` result.

* returns
  * a function that takes an argument `x` to `Some(this(x))` if `this` is
    defined for `x` , and to `None` otherwise.

* Definition Classes
  * PartialFunction
* See also
  * Function.unlift

(defined at scala.PartialFunction)


### `def orElse[A1 <: A, B1 >: B](that: PartialFunction[A1, B1]): PartialFunction[A1, B1]` ###

Composes this partial function with a fallback partial function which gets
applied where this partial function is not defined.

* A1
  * the argument type of the fallback function
* B1
  * the result type of the fallback function
* that
  * the fallback function
* returns
  * a partial function which has as domain the union of the domains of this
    partial function and `that` . The resulting partial function takes `x` to
     `this(x)` where `this` is defined, and to `that(x)` where it is not.

* Definition Classes
  * PartialFunction

(defined at scala.PartialFunction)


### `def runWith[U](action: (B) ⇒ U): (A) ⇒ Boolean`                         ###

Composes this partial function with an action function which gets applied to
results of this partial function. The action function is invoked only for its
side effects; its result is ignored.

Note that expression `pf.runWith(action)(x)` is equivalent to

```scala
if(pf isDefinedAt x) { action(pf(x)); true } else false
```

except that `runWith` is implemented via `applyOrElse` and thus potentially more
efficient. Using `runWith` avoids double evaluation of pattern matchers and
guards for partial function literals.

* action
  * the action function
* returns
  * a function which maps arguments `x` to `isDefinedAt(x)` . The resulting
    function runs `action(this(x))` where `this` is defined.

* Definition Classes
  * PartialFunction
* Since
  * 2.10
* See also
  * `applyOrElse` .

(defined at scala.PartialFunction)


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def equals(that: Any): Boolean`                                         ###

Compares the receiver object ( `this` ) with the argument object ( `that` ) for
equivalence.

Any implementation of this method should be an
[equivalence relation](http://en.wikipedia.org/wiki/Equivalence_relation) :

* It is reflexive: for any instance `x` of type `Any` , `x.equals(x)` should
   return `true` .
* It is symmetric: for any instances `x` and `y` of type `Any` , `x.equals(y)`
   should return `true` if and only if `y.equals(x)` returns `true` .
* It is transitive: for any instances `x` , `y` , and `z` of type `AnyRef` if
    `x.equals(y)` returns `true` and `y.equals(z)` returns `true` , then
    `x.equals(z)` should return `true` .

If you override this method, you should verify that your implementation remains
an equivalence relation. Additionally, when overriding this method it is usually
necessary to override `hashCode` to ensure that objects which are "equal" (
 `o1.equals(o2)` returns `true` ) hash to the same scala.Int. (
 `o1.hashCode.equals(o2.hashCode)` ).

* that
  * the object to compare against this object for equality.
* returns
  * `true` if the receiver object is equivalent to the argument; `false`
    otherwise.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def hashCode(): Int`                                                    ###

Calculate a hash code value for the object.

The default hashing algorithm is platform dependent.

Note that it is allowed for two objects to have identical hash codes (
 `o1.hashCode.equals(o2.hashCode)` ) yet not be equal ( `o1.equals(o2)` returns
 `false` ). A degenerate implementation could always return `0` . However, it is
required that if two objects are equal ( `o1.equals(o2)` returns `true` ) that
they have identical hash codes ( `o1.hashCode.equals(o2.hashCode)` ). Therefore,
when overriding this method, be sure to verify that the behavior is consistent
with the `equals` method.

* returns
  * the hash code value for this object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


--------------------------------------------------------------------------------
            Abstract Value Members From scala.collection.GenMapLike
--------------------------------------------------------------------------------


### `abstract def seq: Map[A, B]`                                            ###

* Definition Classes
  * GenMapLike → Parallelizable → GenTraversableOnce

(defined at scala.collection.GenMapLike)


--------------------------------------------------------------------------------
           Concrete Value Members From scala.collection.IterableLike
--------------------------------------------------------------------------------


### `def canEqual(that: Any): Boolean`                                       ###

Method called from equality methods, so that user-defined subclasses can refuse
to be equal to other collections of the same kind.

* that
  * The object with which this iterable collection should be compared
* returns
  * `true` , if this iterable collection can possibly equal `that` , `false`
    otherwise. The test takes into consideration only the run-time types of
    objects but ignores their elements.

* Definition Classes
  * IterableLike → Equals

(defined at scala.collection.IterableLike)


### `def thisCollection: Iterable[(A, B)]`                                   ###

The underlying collection seen as an instance of `Iterable` . By default this is
implemented as the current collection object itself, but this can be overridden.

* Attributes
  * protected[this]
* Definition Classes
  * IterableLike → TraversableLike

(defined at scala.collection.IterableLike)


### `def toCollection(repr: This): Iterable[(A, B)]`                         ###

A conversion from collections of type `Repr` to `Iterable` objects. By default
this is implemented as just a cast, but this can be overridden.

* Attributes
  * protected[this]
* Definition Classes
  * IterableLike → TraversableLike

(defined at scala.collection.IterableLike)


--------------------------------------------------------------------------------
         Concrete Value Members From scala.collection.IterableProxyLike
--------------------------------------------------------------------------------


### `def dropRight(n: Int): This`                                            ###

Selects all elements except last _n_ ones.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* n
  * The number of elements to take
* returns
  * a iterable collection consisting of all elements of this iterable collection
    except the last `n` ones, or else the empty iterable collection, if this
    iterable collection has less than `n` elements.

* Definition Classes
  * IterableProxyLike → IterableLike

(defined at scala.collection.IterableProxyLike)


### `def grouped(size: Int): Iterator[This]`                                 ###

Partitions elements in fixed size iterable collections.

* size
  * the number of elements per group
* returns
  * An iterator producing iterable collections of size `size` , except the last
    will be less than size `size` if the elements don't divide evenly.

* Definition Classes
  * IterableProxyLike → IterableLike
* See also
  * scala.collection.Iterator, method `grouped`

(defined at scala.collection.IterableProxyLike)


### `def sameElements[B >: (A, B)](that: GenIterable[B]): Boolean`           ###

[use case]

Checks if the other iterable collection contains the same elements in the same
order as this map.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* that
  * the collection to compare with.
* returns
  * `true` , if both collections contain the same elements in the same order,
     `false` otherwise.

* Definition Classes
  * IterableProxyLike → IterableLike → GenIterableLike

(defined at scala.collection.IterableProxyLike)


### `def sliding(size: Int): Iterator[This]`                                 ###

Groups elements in fixed size blocks by passing a "sliding window" over them (as
opposed to partitioning them, as is done in grouped.)

* size
  * the number of elements per group
* returns
  * An iterator producing iterable collections of size `size` , except the last
    and the only element will be truncated if there are fewer elements than
    size.

* Definition Classes
  * IterableProxyLike → IterableLike
* See also
  * scala.collection.Iterator, method `sliding`

(defined at scala.collection.IterableProxyLike)


### `def sliding(size: Int, step: Int): Iterator[This]`                      ###

Groups elements in fixed size blocks by passing a "sliding window" over them (as
opposed to partitioning them, as is done in grouped.)

* size
  * the number of elements per group
* step
  * the distance between the first elements of successive groups (defaults to 1)
* returns
  * An iterator producing iterable collections of size `size` , except the last
    and the only element will be truncated if there are fewer elements than
    size.

* Definition Classes
  * IterableProxyLike → IterableLike
* See also
  * scala.collection.Iterator, method `sliding`

(defined at scala.collection.IterableProxyLike)


### `def takeRight(n: Int): This`                                            ###

Selects last _n_ elements.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* n
  * the number of elements to take
* returns
  * a iterable collection consisting only of the last `n` elements of this
    iterable collection, or else the whole iterable collection, if it has less
    than `n` elements.

* Definition Classes
  * IterableProxyLike → IterableLike

(defined at scala.collection.IterableProxyLike)


### `def view(from: Int, until: Int): IterableView[(A, B), This]`            ###

Creates a non-strict view of a slice of this iterable collection.

Note: the difference between `view` and `slice` is that `view` produces a view
of the current iterable collection, whereas `slice` produces a new iterable
collection.

Note: `view(from, to)` is equivalent to `view.slice(from, to)`

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* from
  * the index of the first element of the view
* until
  * the index of the element following the view
* returns
  * a non-strict view of a slice of this iterable collection, starting at index
     `from` and extending up to (but not including) index `until` .

* Definition Classes
  * IterableProxyLike → TraversableProxyLike → IterableLike → TraversableLike

(defined at scala.collection.IterableProxyLike)


### `def view: IterableView[(A, B), This]`                                   ###

Creates a non-strict view of this iterable collection.

* returns
  * a non-strict view of this iterable collection.

* Definition Classes
  * IterableProxyLike → TraversableProxyLike → IterableLike → TraversableLike

(defined at scala.collection.IterableProxyLike)


### `def zipAll[B, A1 >: (A, B), That](that: GenIterable[B], thisElem: A1, thatElem: B)(implicit bf: CanBuildFrom[This, (A1, B), That]): That` ###

[use case]

Returns a map formed from this map and another iterable collection by combining
corresponding elements in pairs. If one of the two collections is shorter than
the other, placeholder elements are used to extend the shorter collection to the
length of the longer.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* B
  * the type of the second half of the returned pairs
* that
  * The iterable providing the second half of each result pair
* thisElem
  * the element to be used to fill up the result if this map is shorter than
     `that` .
* thatElem
  * the element to be used to fill up the result if `that` is shorter than this
    map.
* returns
  * a new map containing pairs consisting of corresponding elements of this map
    and `that` . The length of the returned collection is the maximum of the
    lengths of this map and `that` . If this map is shorter than `that` ,
     `thisElem` values are used to pad the result. If `that` is shorter than
    this map, `thatElem` values are used to pad the result.

* Definition Classes
  * IterableProxyLike → IterableLike → GenIterableLike

(defined at scala.collection.IterableProxyLike)


### `def zipWithIndex[A1 >: (A, B), That](implicit bf: CanBuildFrom[This, (A1, Int), That]): That` ###

[use case]

Zips this map with its indices.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * A new map containing pairs consisting of all elements of this map paired
    with their index. Indices start at `0` .

* Definition Classes
  * IterableProxyLike → IterableLike → GenIterableLike

Example:

```scala
List("a", "b", "c").zipWithIndex = List(("a", 0), ("b", 1), ("c", 2))
```

(defined at scala.collection.IterableProxyLike)


### `def zip[A1 >: (A, B), B, That](that: GenIterable[B])(implicit bf: CanBuildFrom[This, (A1, B), That]): That` ###

[use case]

Returns a map formed from this map and another iterable collection by combining
corresponding elements in pairs. If one of the two collections is longer than
the other, its remaining elements are ignored.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* B
  * the type of the second half of the returned pairs
* that
  * The iterable providing the second half of each result pair
* returns
  * a new map containing pairs consisting of corresponding elements of this map
    and `that` . The length of the returned collection is the minimum of the
    lengths of this map and `that` .

* Definition Classes
  * IterableProxyLike → IterableLike → GenIterableLike

(defined at scala.collection.IterableProxyLike)


--------------------------------------------------------------------------------
              Abstract Value Members From scala.collection.MapLike
--------------------------------------------------------------------------------


### `abstract def empty: This`                                               ###

The empty map of the same type as this map

* returns
  * an empty map of type `This` .

* Definition Classes
  * MapLike

(defined at scala.collection.MapLike)


--------------------------------------------------------------------------------
              Concrete Value Members From scala.collection.MapLike
--------------------------------------------------------------------------------


### `def newBuilder: Builder[(A, B), This]`                                  ###

A common implementation of `newBuilder` for all maps in terms of `empty` .
Overridden for mutable maps in `mutable.MapLike` .

* Attributes
  * protected[this]
* Definition Classes
  * MapLike → TraversableLike → HasNewBuilder

(defined at scala.collection.MapLike)


### `def parCombiner: Combiner[(A, B), ParMap[A, B]]`                        ###

The default `par` implementation uses the combiner provided by this method to
create a new parallel collection.

* returns
  * a combiner for the parallel collection of type `ParRepr`

* Attributes
  * protected[this]
* Definition Classes
  * MapLike → TraversableLike → Parallelizable

(defined at scala.collection.MapLike)


--------------------------------------------------------------------------------
           Concrete Value Members From scala.collection.MapProxyLike
--------------------------------------------------------------------------------


### `def +[B1 >: B](kv: (A, B1)): Map[A, B1]`                                ###

[use case]

Adds a key/value pair to this map, returning a new map.

* kv
  * the key/value pair
* returns
  * a new map with the new binding added to this map

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def +[B1 >: B](kv1: (A, B1), kv2: (A, B1), kvs: (A, B1)*): Map[A, B1]`  ###

[use case]

Adds key/value pairs to this map, returning a new map.

This method takes two or more key/value pairs. Another overloaded variant of
this method handles the case where a single key/value pair is added.

* kvs
  * the key/value pairs
* returns
  * a new map with the given bindings added to this map

* Definition Classes
  * MapProxyLike → MapLike

(defined at scala.collection.MapProxyLike)


### `def ++[B1 >: B](xs: GenTraversableOnce[(A, B1)]): Map[A, B1]`           ###

[use case]

Adds all key/value pairs in a traversable collection to this map, returning a
new map.

* xs
  * the collection containing the added key/value pairs
* returns
  * a new map with the given bindings added to this map

* Definition Classes
  * MapProxyLike → MapLike

(defined at scala.collection.MapProxyLike)


### `def -(key: A): This`                                                    ###

[use case]

Removes a key from this map, returning a new map.

* key
  * the key to be removed
* returns
  * a new map without a binding for `key`

* Definition Classes
  * MapProxyLike → MapLike → Subtractable → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def addString(b: StringBuilder, start: String, sep: String, end: String): StringBuilder` ###

Appends all elements of this map to a string builder using start, end, and
separator strings. The written text begins with the string `start` and ends with
the string `end` . Inside, the string representations (w.r.t. the method
 `toString` ) of all elements of this map are separated by the string `sep` .

Example:

```scala
scala> val a = List(1,2,3,4)
a: List[Int] = List(1, 2, 3, 4)

scala> val b = new StringBuilder()
b: StringBuilder =

scala> a.addString(b , "List(" , ", " , ")")
res5: StringBuilder = List(1, 2, 3, 4)
```

* b
  * the string builder to which elements are appended.
* start
  * the starting string.
* sep
  * the separator string.
* end
  * the ending string.
* returns
  * the string builder `b` to which elements were appended.

* Definition Classes
  * MapProxyLike → TraversableProxyLike → MapLike → TraversableOnce

(defined at scala.collection.MapProxyLike)


### `def apply(key: A): B`                                                   ###

Retrieves the value which is associated with the given key. This method invokes
the `default` method of the map if there is no mapping from the given key to a
value. Unless overridden, the `default` method throws a
 `NoSuchElementException` .

* key
  * the key
* returns
  * the value associated with the given key, or the result of the map's
     `default` method, if none exists.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike → Function1

(defined at scala.collection.MapProxyLike)


### `def contains(key: A): Boolean`                                          ###

Tests whether this map contains a binding for a key.

* key
  * the key
* returns
  * `true` if there is a binding for `key` in this map, `false` otherwise.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def default(key: A): B`                                                 ###

Defines the default value computation for the map, returned when a key is not
found The method implemented here throws an exception, but it might be
overridden in subclasses.

* key
  * the given key value for which a binding is missing.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike
* Exceptions thrown
  * NoSuchElementException

(defined at scala.collection.MapProxyLike)


### `def filterKeys(p: (A) ⇒ Boolean): Map[A, B]`                            ###

Filters this map by retaining only keys satisfying a predicate.

* p
  * the predicate used to test keys
* returns
  * an immutable map consisting only of those key value pairs of this map where
    the key satisfies the predicate `p` . The resulting map wraps the original
    map without copying any elements.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def filterNot(p: ((A, B)) ⇒ Boolean): This`                             ###

Selects all elements of this map which do not satisfy a predicate.

* p
  * the predicate used to test elements.
* returns
  * a new map consisting of all elements of this map that do not satisfy the
    given predicate `p` . The order of the elements is preserved.

* Definition Classes
  * MapProxyLike → TraversableProxyLike → MapLike → TraversableLike →
    GenTraversableLike

(defined at scala.collection.MapProxyLike)


### `def get(key: A): Option[B]`                                             ###

Optionally returns the value associated with a key.

* key
  * the key value
* returns
  * an option value containing the value associated with `key` in this map, or
     `None` if none exists.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def getOrElse[B1 >: B](key: A, default: ⇒ B1): B1`                      ###

[use case]

Returns the value associated with a key, or a default value if the key is not
contained in the map.

* key
  * the key.
* default
  * a computation that yields a default value in case no binding for `key` is
    found in the map.
* returns
  * the value associated with `key` if it exists, otherwise the result of the
     `default` computation.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def isDefinedAt(key: A): Boolean`                                       ###

Tests whether this map contains a binding for a key. This method, which
implements an abstract method of trait `PartialFunction` , is equivalent to
 `contains` .

* key
  * the key
* returns
  * `true` if there is a binding for `key` in this map, `false` otherwise.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike → PartialFunction

(defined at scala.collection.MapProxyLike)


### `def isEmpty: Boolean`                                                   ###

Tests whether this map is empty.

* returns
  * `true` if the map contain no elements, `false` otherwise.

* Definition Classes
  * MapProxyLike → TraversableProxyLike → MapLike → IterableLike →
    TraversableLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.MapProxyLike)


### `def iterator: Iterator[(A, B)]`                                         ###

Creates a new iterator over all elements contained in this iterable object.

* returns
  * the new iterator

* Definition Classes
  * MapProxyLike → IterableProxyLike → MapLike → IterableLike → GenIterableLike

(defined at scala.collection.MapProxyLike)


### `def keySet: Set[A]`                                                     ###

Collects all keys of this map in a set.

* returns
  * a set containing all keys of this map.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def keys: Iterable[A]`                                                  ###

Collects all keys of this map in an iterable collection.

* returns
  * the keys of this map as an iterable.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def keysIterator: Iterator[A]`                                          ###

Creates an iterator for all keys.

* returns
  * an iterator over all keys.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def mapValues[C](f: (B) ⇒ C): Map[A, C]`                                ###

Transforms this map by applying a function to every retrieved value.

* f
  * the function used to transform values of this map.
* returns
  * a map view which maps every key of this map to `f(this(key))` . The
    resulting map wraps the original map without copying any elements.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def updated[B1 >: B](key: A, value: B1): Map[A, B1]`                    ###

[use case]

Creates a new map obtained by updating this map with a given key/value pair.

* key
  * the key
* value
  * the value
* returns
  * A new map with the new key/value mapping added to this map.

* Definition Classes
  * MapProxyLike → MapLike

(defined at scala.collection.MapProxyLike)


### `def values: Iterable[B]`                                                ###

Collects all values of this map in an iterable collection.

* returns
  * the values of this map as an iterable.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


### `def valuesIterator: Iterator[B]`                                        ###

Creates an iterator for all values in this map.

* returns
  * an iterator over all values that are associated with some key in this map.

* Definition Classes
  * MapProxyLike → MapLike → GenMapLike

(defined at scala.collection.MapProxyLike)


--------------------------------------------------------------------------------
          Concrete Value Members From scala.collection.Parallelizable
--------------------------------------------------------------------------------


### `def par: ParMap[A, B]`                                                  ###

Returns a parallel implementation of this collection.

For most collection types, this method creates a new parallel collection by
copying all the elements. For these collection, `par` takes linear time. Mutable
collections in this category do not produce a mutable parallel collection that
has the same underlying dataset, so changes in one collection will not be
reflected in the other one.

Specific collections (e.g. `ParArray` or `mutable.ParHashMap` ) override this
default behaviour by creating a parallel collection which shares the same
underlying dataset. For these collections, `par` takes constant or sublinear
time.

All parallel collections return a reference to themselves.

* returns
  * a parallel implementation of this collection

* Definition Classes
  * Parallelizable

(defined at scala.collection.Parallelizable)


--------------------------------------------------------------------------------
          Concrete Value Members From scala.collection.TraversableLike
--------------------------------------------------------------------------------


### `def ++:[B >: (A, B), That](that: Traversable[B])(implicit bf: CanBuildFrom[This, B, That]): That` ###

As with `++` , returns a new collection containing the elements from the left
operand followed by the elements from the right operand.

It differs from `++` in that the right operand determines the type of the
resulting collection rather than the left one. Mnemonic: the COLon is on the
side of the new COLlection type.

Example:

```scala
scala> val x = List(1)
x: List[Int] = List(1)

scala> val y = LinkedList(2)
y: scala.collection.mutable.LinkedList[Int] = LinkedList(2)

scala> val z = x ++: y
z: scala.collection.mutable.LinkedList[Int] = LinkedList(1, 2)
```

This overload exists because: for the implementation of `++:` we should reuse
that of `++` because many collections override it with more efficient versions.

Since `TraversableOnce` has no `++` method, we have to implement that directly,
but `Traversable` and down can use the overload.

* B
  * the element type of the returned collection.
* That
  * the class of the returned collection. Where possible, `That` is the same
    class as the current collection class `Repr` , but this depends on the
    element type `B` being admissible for that class, which means that an
    implicit instance of type `CanBuildFrom[Repr, B, That]` is found.
* that
  * the traversable to append.
* bf
  * an implicit value of class `CanBuildFrom` which determines the result class
     `That` from the current representation type `Repr` and and the new element
    type `B` .
* returns
  * a new collection of type `That` which contains all elements of this
    traversable collection followed by all elements of `that` .

* Definition Classes
  * TraversableLike

(defined at scala.collection.TraversableLike)


### `def ++:[B >: (A, B), That](that: TraversableOnce[B])(implicit bf: CanBuildFrom[This, B, That]): That` ###

[use case]

As with `++` , returns a new collection containing the elements from the left
operand followed by the elements from the right operand.

It differs from `++` in that the right operand determines the type of the
resulting collection rather than the left one. Mnemonic: the COLon is on the
side of the new COLlection type.

Example:

```scala
scala> val x = List(1)
x: List[Int] = List(1)

scala> val y = LinkedList(2)
y: scala.collection.mutable.LinkedList[Int] = LinkedList(2)

scala> val z = x ++: y
z: scala.collection.mutable.LinkedList[Int] = LinkedList(1, 2)
```

* B
  * the element type of the returned collection.
* that
  * the traversable to append.
* returns
  * a new map which contains all elements of this map followed by all elements
    of `that` .

* Definition Classes
  * TraversableLike

(defined at scala.collection.TraversableLike)


### `def inits: Iterator[This]`                                              ###

Iterates over the inits of this traversable collection. The first value will be
this traversable collection and the final one will be an empty traversable
collection, with the intervening values the results of successive applications
of `init` .

* returns
  * an iterator over all the inits of this traversable collection

* Definition Classes
  * TraversableLike

Example:

```scala
List(1,2,3).inits = Iterator(List(1,2,3), List(1,2), List(1), Nil)
```

(defined at scala.collection.TraversableLike)


### `final def isTraversableAgain: Boolean`                                  ###

Tests whether this traversable collection can be repeatedly traversed.

* returns
  * `true`

* Definition Classes
  * TraversableLike → GenTraversableLike → GenTraversableOnce

(defined at scala.collection.TraversableLike)


### `def repr: This`                                                         ###

The collection of type traversable collection underlying this `TraversableLike`
object. By default this is implemented as the `TraversableLike` object itself,
but this can be overridden.

* Definition Classes
  * TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableLike)


### `def scan[B >: (A, B), That](z: B)(op: (B, B) ⇒ B)(implicit cbf: CanBuildFrom[This, B, That]): That` ###

Computes a prefix scan of the elements of the collection.

Note: The neutral element `z` may be applied more than once.

* B
  * element type of the resulting collection
* That
  * type of the resulting collection
* z
  * neutral element for the operator `op`
* op
  * the associative operator for the scan
* cbf
  * combiner factory which provides a combiner
* returns
  * a new traversable collection containing the prefix scan of the elements in
    this traversable collection

* Definition Classes
  * TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableLike)


### `def tails: Iterator[This]`                                              ###

Iterates over the tails of this traversable collection. The first value will be
this traversable collection and the final one will be an empty traversable
collection, with the intervening values the results of successive applications
of `tail` .

* returns
  * an iterator over all the tails of this traversable collection

* Definition Classes
  * TraversableLike

Example:

```scala
List(1,2,3).tails = Iterator(List(1,2,3), List(2,3), List(3), Nil)
```

(defined at scala.collection.TraversableLike)


### `def to[Col[_]](implicit cbf: CanBuildFrom[Nothing, (A, B), Col[(A, B)]]): Col[(A, B)]` ###

[use case]

Converts this map into another by copying all elements.

* Col
  * The collection type to build.
* returns
  * a new collection containing all elements of this map.

* Definition Classes
  * TraversableLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableLike)


### `def withFilter(p: ((A, B)) ⇒ Boolean): FilterMonadic[(A, B), This]`     ###

Creates a non-strict filter of this traversable collection.

Note: the difference between `c filter p` and `c withFilter p` is that the
former creates a new collection, whereas the latter only restricts the domain of
subsequent `map` , `flatMap` , `foreach` , and `withFilter` operations.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* p
  * the predicate used to test elements.
* returns
  * an object of class `WithFilter` , which supports `map` , `flatMap` ,
     `foreach` , and `withFilter` operations. All these operations apply to
    those elements of this traversable collection which satisfy the predicate
     `p` .

* Definition Classes
  * TraversableLike → FilterMonadic

(defined at scala.collection.TraversableLike)


--------------------------------------------------------------------------------
          Concrete Value Members From scala.collection.TraversableOnce
--------------------------------------------------------------------------------


### `def aggregate[B](z: ⇒ B)(seqop: (B, (A, B)) ⇒ B, combop: (B, B) ⇒ B): B` ###

Aggregates the results of applying an operator to subsequent elements.

This is a more general form of `fold` and `reduce` . It has similar semantics,
but does not require the result to be a supertype of the element type. It
traverses the elements in different partitions sequentially, using `seqop` to
update the result, and then applies `combop` to results from different
partitions. The implementation of this operation may operate on an arbitrary
number of collection partitions, so `combop` may be invoked an arbitrary number
of times.

For example, one might want to process some elements and then produce a `Set` .
In this case, `seqop` would process an element and append it to the list, while
 `combop` would concatenate two lists from different partitions together. The
initial value `z` would be an empty set.

```scala
pc.aggregate(Set[Int]())(_ += process(_), _ ++ _)
```

Another example is calculating geometric mean from a collection of doubles (one
would typically require big doubles for this).

* B
  * the type of accumulated results
* z
  * the initial value for the accumulated result of the partition - this will
    typically be the neutral element for the `seqop` operator (e.g. `Nil` for
    list concatenation or `0` for summation) and may be evaluated more than once
* seqop
  * an operator used to accumulate results within a partition
* combop
  * an associative operator used to combine results from different partitions

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


### `def collectFirst[B](pf: PartialFunction[(A, B), B]): Option[B]`         ###

Finds the first element of the traversable or iterator for which the given
partial function is defined, and applies the partial function to it.

Note: may not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* pf
  * the partial function
* returns
  * an option value containing pf applied to the first value for which it is
    defined, or `None` if none exists.

* Definition Classes
  * TraversableOnce

Example:

```scala
Seq("a", 1, 5L).collectFirst({ case x: Int => x*10 }) = Some(10)
```

(defined at scala.collection.TraversableOnce)


### `def fold[A1 >: (A, B)](z: A1)(op: (A1, A1) ⇒ A1): A1`                   ###

Folds the elements of this traversable or iterator using the specified
associative binary operator.

The order in which operations are performed on elements is unspecified and may
be nondeterministic.

* A1
  * a type parameter for the binary operator, a supertype of `A` .
* z
  * a neutral element for the fold operation; may be added to the result an
    arbitrary number of times, and must not change the result (e.g., `Nil` for
    list concatenation, 0 for addition, or 1 for multiplication.)
* op
  * a binary operator that must be associative
* returns
  * the result of applying fold operator `op` between all the elements and `z`

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


### `def maxBy[B](f: ((A, B)) ⇒ B)(implicit cmp: Ordering[B]): (A, B)`       ###

[use case]

Finds the first element which yields the largest value measured by function f.

* B
  * The result type of the function f.
* f
  * The measuring function.
* returns
  * the first element of this map with the largest value measured by function f.

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


### `def minBy[B](f: ((A, B)) ⇒ B)(implicit cmp: Ordering[B]): (A, B)`       ###

[use case]

Finds the first element which yields the smallest value measured by function f.

* B
  * The result type of the function f.
* f
  * The measuring function.
* returns
  * the first element of this map with the smallest value measured by function
    f.

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


### `def reduceOption[A1 >: (A, B)](op: (A1, A1) ⇒ A1): Option[A1]`          ###

Reduces the elements of this traversable or iterator, if any, using the
specified associative binary operator.

The order in which operations are performed on elements is unspecified and may
be nondeterministic.

* A1
  * A type parameter for the binary operator, a supertype of `A` .
* op
  * A binary operator that must be associative.
* returns
  * An option value containing result of applying reduce operator `op` between
    all the elements if the collection is nonempty, and `None` otherwise.

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


### `def reduce[A1 >: (A, B)](op: (A1, A1) ⇒ A1): A1`                        ###

Reduces the elements of this traversable or iterator using the specified
associative binary operator.

The order in which operations are performed on elements is unspecified and may
be nondeterministic.

* A1
  * A type parameter for the binary operator, a supertype of `A` .
* op
  * A binary operator that must be associative.
* returns
  * The result of applying reduce operator `op` between all the elements if the
    traversable or iterator is nonempty.

* Definition Classes
  * TraversableOnce → GenTraversableOnce
* Exceptions thrown
  * UnsupportedOperationException if this traversable or iterator is empty.

(defined at scala.collection.TraversableOnce)


### `def reversed: List[(A, B)]`                                             ###

* Attributes
  * protected[this]
* Definition Classes
  * TraversableOnce

(defined at scala.collection.TraversableOnce)


### `def toVector: Vector[(A, B)]`                                           ###

Converts this traversable or iterator to a Vector.

Note: will not terminate for infinite-sized collections.

* returns
  * a vector containing all elements of this traversable or iterator.

* Definition Classes
  * TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableOnce)


--------------------------------------------------------------------------------
       Abstract Value Members From scala.collection.TraversableProxyLike
--------------------------------------------------------------------------------


### `abstract def self: This`                                                ###

* Definition Classes
  * TraversableProxyLike → Proxy

(defined at scala.collection.TraversableProxyLike)


--------------------------------------------------------------------------------
       Concrete Value Members From scala.collection.TraversableProxyLike
--------------------------------------------------------------------------------


### `def ++[B >: (A, B), That](xs: GenTraversableOnce[B])(implicit bf: CanBuildFrom[This, B, That]): That` ###

[use case]

Returns a new map containing the elements from the left hand operand followed by
the elements from the right hand operand. The element type of the map is the
most specific superclass encompassing the element types of the two operands.

Example:

```scala
scala> val a = List(1)
a: List[Int] = List(1)

scala> val b = List(2)
b: List[Int] = List(2)

scala> val c = a ++ b
c: List[Int] = List(1, 2)

scala> val d = List('a')
d: List[Char] = List(a)

scala> val e = c ++ d
e: List[AnyVal] = List(1, 2, a)
```

* B
  * the element type of the returned collection.
* that
  * the traversable to append.
* returns
  * a new map which contains all elements of this map followed by all elements
    of `that` .

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def /:[B](z: B)(op: (B, (A, B)) ⇒ B): B`                                ###

Applies a binary operator to a start value and all elements of this traversable
collection, going left to right.

Note: `/:` is alternate syntax for `foldLeft` ; `z /: xs` is the same as
 `xs foldLeft z` .

Examples:

Note that the folding function used to compute b is equivalent to that used to
compute c.

```scala
scala> val a = List(1,2,3,4)
a: List[Int] = List(1, 2, 3, 4)

scala> val b = (5 /: a)(_+_)
b: Int = 15

scala> val c = (5 /: a)((x,y) => x + y)
c: Int = 15
```

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* z
  * the start value.
* op
  * the binary operator.
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going left to right with the start value `z` on the
    left:

    ```scala
    op(...op(op(z, x_1), x_2), ..., x_n)
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def :\[B](z: B)(op: ((A, B), B) ⇒ B): B`                                ###

Applies a binary operator to all elements of this traversable collection and a
start value, going right to left.

Note: `:\` is alternate syntax for `foldRight` ; `xs :\ z` is the same as
 `xs foldRight z` .

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

Examples:

Note that the folding function used to compute b is equivalent to that used to
compute c.

```scala
scala> val a = List(1,2,3,4)
a: List[Int] = List(1, 2, 3, 4)

scala> val b = (a :\ 5)(_+_)
b: Int = 15

scala> val c = (a :\ 5)((x,y) => x + y)
c: Int = 15
```

* B
  * the result type of the binary operator.
* z
  * the start value
* op
  * the binary operator
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going right to left with the start value `z` on the
    right:

    ```scala
    op(x_1, op(x_2, ... op(x_n, z)...))
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def addString(b: mutable.StringBuilder): mutable.StringBuilder`         ###

Appends all elements of this traversable collection to a string builder. The
written text consists of the string representations (w.r.t. the method
 `toString` ) of all elements of this traversable collection without any
separator string.

Example:

```scala
scala> val a = List(1,2,3,4)
a: List[Int] = List(1, 2, 3, 4)

scala> val b = new StringBuilder()
b: StringBuilder =

scala> val h = a.addString(b)
h: StringBuilder = 1234
```

* b
  * the string builder to which elements are appended.
* returns
  * the string builder `b` to which elements were appended.

* Definition Classes
  * TraversableProxyLike → TraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def addString(b: mutable.StringBuilder, sep: String): mutable.StringBuilder` ###

Appends all elements of this traversable collection to a string builder using a
separator string. The written text consists of the string representations
(w.r.t. the method `toString` ) of all elements of this traversable collection,
separated by the string `sep` .

Example:

```scala
scala> val a = List(1,2,3,4)
a: List[Int] = List(1, 2, 3, 4)

scala> val b = new StringBuilder()
b: StringBuilder =

scala> a.addString(b, ", ")
res0: StringBuilder = 1, 2, 3, 4
```

* b
  * the string builder to which elements are appended.
* sep
  * the separator string.
* returns
  * the string builder `b` to which elements were appended.

* Definition Classes
  * TraversableProxyLike → TraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def collect[B, That](pf: PartialFunction[(A, B), B])(implicit bf: CanBuildFrom[This, B, That]): That` ###

[use case]

Builds a new collection by applying a partial function to all elements of this
map on which the function is defined.

* B
  * the element type of the returned collection.
* pf
  * the partial function which filters and maps the map.
* returns
  * a new map resulting from applying the given partial function `pf` to each
    element on which it is defined and collecting the results. The order of the
    elements is preserved.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def copyToArray[B >: (A, B)](xs: Array[B]): Unit`                       ###

[use case]

Copies values of this map to an array. Fills the given array `xs` with values of
this map. Copying will stop once either the end of the current map is reached,
or the end of the array is reached.

* xs
  * the array to fill.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def copyToArray[B >: (A, B)](xs: Array[B], start: Int): Unit`           ###

[use case]

Copies values of this map to an array. Fills the given array `xs` with values of
this map, beginning at index `start` . Copying will stop once either the end of
the current map is reached, or the end of the array is reached.

* xs
  * the array to fill.
* start
  * the starting index.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def copyToArray[B >: (A, B)](xs: Array[B], start: Int, len: Int): Unit` ###

[use case]

Copies elements of this map to an array. Fills the given array `xs` with at most
 `len` elements of this map, starting at position `start` . Copying will stop
once either the end of the current map is reached, or the end of the array is
reached, or `len` elements have been copied.

* xs
  * the array to fill.
* start
  * the starting index.
* len
  * the maximal number of elements to copy.

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def copyToBuffer[B >: (A, B)](dest: Buffer[B]): Unit`                   ###

Copies all elements of this traversable collection to a buffer.

Note: will not terminate for infinite-sized collections.

* dest
  * The buffer to which elements are copied.

* Definition Classes
  * TraversableProxyLike → TraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def count(p: ((A, B)) ⇒ Boolean): Int`                                  ###

Counts the number of elements in the traversable collection which satisfy a
predicate.

* p
  * the predicate used to test elements.
* returns
  * the number of elements satisfying the predicate `p` .

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def drop(n: Int): This`                                                 ###

Selects all elements except first _n_ ones.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* n
  * the number of elements to drop from this traversable collection.
* returns
  * a traversable collection consisting of all elements of this traversable
    collection except the first `n` ones, or else the empty traversable
    collection, if this traversable collection has less than `n` elements.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def dropWhile(p: ((A, B)) ⇒ Boolean): This`                             ###

Drops longest prefix of elements that satisfy a predicate.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * the longest suffix of this traversable collection whose first element does
    not satisfy the predicate `p` .

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def exists(p: ((A, B)) ⇒ Boolean): Boolean`                             ###

Tests whether a predicate holds for some of the elements of this traversable
collection.

Note: may not terminate for infinite-sized collections.

* p
  * the predicate used to test elements.
* returns
  * `false` if this traversable collection is empty, otherwise `true` if the
    given predicate `p` holds for some of the elements of this traversable
    collection, otherwise `false`

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def filter(p: ((A, B)) ⇒ Boolean): This`                                ###

Selects all elements of this traversable collection which satisfy a predicate.

* p
  * the predicate used to test elements.
* returns
  * a new traversable collection consisting of all elements of this traversable
    collection that satisfy the given predicate `p` . The order of the elements
    is preserved.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def find(p: ((A, B)) ⇒ Boolean): Option[(A, B)]`                        ###

Finds the first element of the traversable collection satisfying a predicate, if
any.

Note: may not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* p
  * the predicate used to test elements.
* returns
  * an option value containing the first element in the traversable collection
    that satisfies `p` , or `None` if none exists.

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def flatMap[B, That](f: ((A, B)) ⇒ GenTraversableOnce[B])(implicit bf: CanBuildFrom[This, B, That]): That` ###

[use case]

Builds a new collection by applying a function to all elements of this map and
using the elements of the resulting collections.

For example:

```scala
def getWords(lines: Seq[String]): Seq[String] = lines flatMap (line => line split "\\W+")
```

The type of the resulting collection is guided by the static type of map. This
might cause unexpected results sometimes. For example:

```scala
// lettersOf will return a Seq[Char] of likely repeated letters, instead of a Set
def lettersOf(words: Seq[String]) = words flatMap (word => word.toSet)

// lettersOf will return a Set[Char], not a Seq
def lettersOf(words: Seq[String]) = words.toSet flatMap (word => word.toSeq)

// xs will be an Iterable[Int]
val xs = Map("a" -> List(11,111), "b" -> List(22,222)).flatMap(_._2)

// ys will be a Map[Int, Int]
val ys = Map("a" -> List(1 -> 11,1 -> 111), "b" -> List(2 -> 22,2 -> 222)).flatMap(_._2)
```

* B
  * the element type of the returned collection.
* f
  * the function to apply to each element.
* returns
  * a new map resulting from applying the given collection-valued function `f`
    to each element of this map and concatenating the results.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike → FilterMonadic

(defined at scala.collection.TraversableProxyLike)


### `def foldLeft[B](z: B)(op: (B, (A, B)) ⇒ B): B`                          ###

Applies a binary operator to a start value and all elements of this traversable
collection, going left to right.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* z
  * the start value.
* op
  * the binary operator.
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going left to right with the start value `z` on the
    left:

    ```scala
    op(...op(z, x_1), x_2, ..., x_n)
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def foldRight[B](z: B)(op: ((A, B), B) ⇒ B): B`                         ###

Applies a binary operator to all elements of this traversable collection and a
start value, going right to left.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* z
  * the start value.
* op
  * the binary operator.
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going right to left with the start value `z` on the
    right:

    ```scala
    op(x_1, op(x_2, ... op(x_n, z)...))
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def forall(p: ((A, B)) ⇒ Boolean): Boolean`                             ###

Tests whether a predicate holds for all elements of this traversable collection.

Note: may not terminate for infinite-sized collections.

* p
  * the predicate used to test elements.
* returns
  * `true` if this traversable collection is empty, otherwise `true` if the
    given predicate `p` holds for all elements of this traversable collection,
    otherwise `false` .

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def foreach[B](f: ((A, B)) ⇒ B): Unit`                                  ###

[use case]

Applies a function `f` to all elements of this map.

Note: this method underlies the implementation of most other bulk operations.
It's important to implement this method in an efficient way.

* f
  * the function that is applied for its side-effect to every element. The
    result of function `f` is discarded.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike →
    TraversableOnce → GenTraversableOnce → FilterMonadic

(defined at scala.collection.TraversableProxyLike)


### `def groupBy[K](f: ((A, B)) ⇒ K): immutable.Map[K, This]`                ###

Partitions this traversable collection into a map of traversable collections
according to some discriminator function.

Note: this method is not re-implemented by views. This means when applied to a
view it will always force the view and return a new traversable collection.

* K
  * the type of keys returned by the discriminator function.
* f
  * the discriminator function.
* returns
  * A map from keys to traversable collections such that the following invariant
    holds:

    ```scala
    (xs groupBy f)(k) = xs filter (x => f(x) == k)
    ```

    That is, every key `k` is bound to a traversable collection of those
    elements `x` for which `f(x)` equals `k` .

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def hasDefiniteSize: Boolean`                                           ###

Tests whether this traversable collection is known to have a finite size. All
strict collections are known to have finite size. For a non-strict collection
such as `Stream` , the predicate returns `true` if all elements have been
computed. It returns `false` if the stream is not yet evaluated to the end.

Note: many collection methods will not work on collections of infinite sizes.

* returns
  * `true` if this collection is known to have finite size, `false` otherwise.

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def head: (A, B)`                                                       ###

Selects the first element of this traversable collection.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * the first element of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike
* Exceptions thrown
  * NoSuchElementException if the traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def headOption: Option[(A, B)]`                                         ###

Optionally selects the first element.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * the first element of this traversable collection if it is nonempty, `None`
    if it is empty.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def init: This`                                                         ###

Selects all elements except the last.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * a traversable collection consisting of all elements of this traversable
    collection except the last one.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike
* Exceptions thrown
  * UnsupportedOperationException if the traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def last: (A, B)`                                                       ###

Selects the last element.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * The last element of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike
* Exceptions thrown
  * NoSuchElementException If the traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def lastOption: Option[(A, B)]`                                         ###

Optionally selects the last element.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * the last element of this traversable collection$ if it is nonempty, `None`
    if it is empty.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def map[B, That](f: ((A, B)) ⇒ B)(implicit bf: CanBuildFrom[This, B, That]): That` ###

[use case]

Builds a new collection by applying a function to all elements of this map.

* B
  * the element type of the returned collection.
* f
  * the function to apply to each element.
* returns
  * a new map resulting from applying the given function `f` to each element of
    this map and collecting the results.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike → FilterMonadic

(defined at scala.collection.TraversableProxyLike)


### `def max[B >: (A, B)](implicit cmp: Ordering[B]): (A, B)`                ###

[use case]

Finds the largest element.

* returns
  * the largest element of this map.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def min[B >: (A, B)](implicit cmp: Ordering[B]): (A, B)`                ###

[use case]

Finds the smallest element.

* returns
  * the smallest element of this map

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def mkString(sep: String): String`                                      ###

Displays all elements of this traversable collection in a string using a
separator string.

* sep
  * the separator string.
* returns
  * a string representation of this traversable collection. In the resulting
    string the string representations (w.r.t. the method `toString` ) of all
    elements of this traversable collection are separated by the string `sep` .

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

Example:

```scala
List(1, 2, 3).mkString("|") = "1|2|3"
```

(defined at scala.collection.TraversableProxyLike)


### `def mkString(start: String, sep: String, end: String): String`          ###

Displays all elements of this traversable collection in a string using start,
end, and separator strings.

* start
  * the starting string.
* sep
  * the separator string.
* end
  * the ending string.
* returns
  * a string representation of this traversable collection. The resulting string
    begins with the string `start` and ends with the string `end` . Inside, the
    string representations (w.r.t. the method `toString` ) of all elements of
    this traversable collection are separated by the string `sep` .

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

Example:

```scala
List(1, 2, 3).mkString("(", "; ", ")") = "(1; 2; 3)"
```

(defined at scala.collection.TraversableProxyLike)


### `def mkString: String`                                                   ###

Displays all elements of this traversable collection in a string.

* returns
  * a string representation of this traversable collection. In the resulting
    string the string representations (w.r.t. the method `toString` ) of all
    elements of this traversable collection follow each other without any
    separator string.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def nonEmpty: Boolean`                                                  ###

Tests whether the traversable collection is not empty.

* returns
  * `true` if the traversable collection contains at least one element, `false`
    otherwise.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def partition(p: ((A, B)) ⇒ Boolean): (This, This)`                     ###

Partitions this traversable collection in two traversable collections according
to a predicate.

* p
  * the predicate on which to partition.
* returns
  * a pair of traversable collections: the first traversable collection consists
    of all elements that satisfy the predicate `p` and the second traversable
    collection consists of all elements that don't. The relative order of the
    elements in the resulting traversable collections is the same as in the
    original traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def product[B >: (A, B)](implicit num: Numeric[B]): B`                  ###

[use case]

Multiplies up the elements of this collection.

* returns
  * the product of all elements in this map of numbers of type `Int` . Instead
    of `Int` , any other type `T` with an implicit `Numeric[T]` implementation
    can be used as element type of the map and as result type of `product` .
    Examples of such types are: `Long` , `Float` , `Double` , `BigInt` .

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def reduceLeftOption[B >: (A, B)](op: (B, (A, B)) ⇒ B): Option[B]`      ###

Optionally applies a binary operator to all elements of this traversable
collection, going left to right.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* op
  * the binary operator.
* returns
  * an option value containing the result of `reduceLeft(op)` is this
    traversable collection is nonempty, `None` otherwise.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def reduceLeft[B >: (A, B)](op: (B, (A, B)) ⇒ B): B`                    ###

Applies a binary operator to all elements of this traversable collection, going
left to right.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* op
  * the binary operator.
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going left to right:

    ```scala
    op( op( ... op(x_1, x_2) ..., x_{n-1}), x_n)
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce
* Exceptions thrown
  * UnsupportedOperationException if this traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def reduceRightOption[B >: (A, B)](op: ((A, B), B) ⇒ B): Option[B]`     ###

Optionally applies a binary operator to all elements of this traversable
collection, going right to left.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* op
  * the binary operator.
* returns
  * an option value containing the result of `reduceRight(op)` is this
    traversable collection is nonempty, `None` otherwise.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def reduceRight[B >: (A, B)](op: ((A, B), B) ⇒ B): B`                   ###

Applies a binary operator to all elements of this traversable collection, going
right to left.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered. or the operator is associative and commutative.

* B
  * the result type of the binary operator.
* op
  * the binary operator.
* returns
  * the result of inserting `op` between consecutive elements of this
    traversable collection, going right to left:

    ```scala
    op(x_1, op(x_2, ..., op(x_{n-1}, x_n)...))
    ```

    where `x1, ..., xn` are the elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce
* Exceptions thrown
  * UnsupportedOperationException if this traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def scanLeft[B, That](z: B)(op: (B, (A, B)) ⇒ B)(implicit bf: CanBuildFrom[This, B, That]): That` ###

Produces a collection containing cumulative results of applying the operator
going left to right.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* B
  * the type of the elements in the resulting collection
* That
  * the actual type of the resulting collection
* z
  * the initial value
* op
  * the binary operator applied to the intermediate result and the element
* bf
  * an implicit value of class `CanBuildFrom` which determines the result class
     `That` from the current representation type `Repr` and and the new element
    type `B` .
* returns
  * collection with intermediate results

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def scanRight[B, That](z: B)(op: ((A, B), B) ⇒ B)(implicit bf: CanBuildFrom[This, B, That]): That` ###

Produces a collection containing cumulative results of applying the operator
going right to left. The head of the collection is the last cumulative result.

Note: will not terminate for infinite-sized collections.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

Example:

```scala
List(1, 2, 3, 4).scanRight(0)(_ + _) == List(10, 9, 7, 4, 0)
```

* B
  * the type of the elements in the resulting collection
* That
  * the actual type of the resulting collection
* z
  * the initial value
* op
  * the binary operator applied to the intermediate result and the element
* bf
  * an implicit value of class `CanBuildFrom` which determines the result class
     `That` from the current representation type `Repr` and and the new element
    type `B` .
* returns
  * collection with intermediate results

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def size: Int`                                                          ###

The size of this traversable collection.

Note: will not terminate for infinite-sized collections.

* returns
  * the number of elements in this traversable collection.

* Definition Classes
  * TraversableProxyLike → GenTraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def slice(from: Int, until: Int): This`                                 ###

Selects an interval of elements. The returned collection is made up of all
elements `x` which satisfy the invariant:

```scala
from <= indexOf(x) < until
```

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * a traversable collection containing the elements greater than or equal to
    index `from` extending up to (but not including) index `until` of this
    traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def span(p: ((A, B)) ⇒ Boolean): (This, This)`                          ###

Splits this traversable collection into a prefix/suffix pair according to a
predicate.

Note: `c span p` is equivalent to (but possibly more efficient than)
 `(c takeWhile p, c dropWhile p)` , provided the evaluation of the predicate
 `p` does not cause any side-effects.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * a pair consisting of the longest prefix of this traversable collection whose
    elements all satisfy `p` , and the rest of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def splitAt(n: Int): (This, This)`                                      ###

Splits this traversable collection into two at a given position. Note:
 `c splitAt n` is equivalent to (but possibly more efficient than)
 `(c take n, c drop n)` .

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* n
  * the position at which to split.
* returns
  * a pair of traversable collections consisting of the first `n` elements of
    this traversable collection, and the other elements.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def stringPrefix: String`                                               ###

Defines the prefix of this object's `toString` representation.

* returns
  * a string representation which starts the result of `toString` applied to
    this traversable collection. By default the string prefix is the simple name
    of the collection class traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def sum[B >: (A, B)](implicit num: Numeric[B]): B`                      ###

[use case]

Sums up the elements of this collection.

* returns
  * the sum of all elements in this map of numbers of type `Int` . Instead of
     `Int` , any other type `T` with an implicit `Numeric[T]` implementation can
    be used as element type of the map and as result type of `sum` . Examples of
    such types are: `Long` , `Float` , `Double` , `BigInt` .

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def tail: This`                                                         ###

Selects all elements except the first.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * a traversable collection consisting of all elements of this traversable
    collection except the first one.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike
* Exceptions thrown
  * ``UnsupportedOperationException`` if the traversable collection is empty.

(defined at scala.collection.TraversableProxyLike)


### `def take(n: Int): This`                                                 ###

Selects first _n_ elements.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* n
  * the number of elements to take from this traversable collection.
* returns
  * a traversable collection consisting only of the first `n` elements of this
    traversable collection, or else the whole traversable collection, if it has
    less than `n` elements.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def takeWhile(p: ((A, B)) ⇒ Boolean): This`                             ###

Takes longest prefix of elements that satisfy a predicate.

Note: might return different results for different runs, unless the underlying
collection type is ordered.

* returns
  * the longest prefix of this traversable collection whose elements all satisfy
    the predicate `p` .

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableLike

(defined at scala.collection.TraversableProxyLike)


### `def toArray[B >: (A, B)](implicit arg0: ClassTag[B]): Array[B]`         ###

[use case]

Converts this map to an array.

* returns
  * an array containing all elements of this map. An `ClassTag` must be
    available for the element type of this map.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toBuffer[B >: (A, B)]: Buffer[B]`                                   ###

Uses the contents of this traversable collection to create a new mutable buffer.

Note: will not terminate for infinite-sized collections.

* returns
  * a buffer containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toIndexedSeq: immutable.IndexedSeq[(A, B)]`                         ###

Converts this traversable collection to an indexed sequence.

Note: will not terminate for infinite-sized collections.

* returns
  * an indexed sequence containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toIterable: Iterable[(A, B)]`                                       ###

Converts this traversable collection to an iterable collection. Note that the
choice of target `Iterable` is lazy in this default implementation as this
 `TraversableOnce` may be lazy and unevaluated (i.e. it may be an iterator which
is only traversable once).

Note: will not terminate for infinite-sized collections.

* returns
  * an `Iterable` containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toIterator: Iterator[(A, B)]`                                       ###

Returns an Iterator over the elements in this traversable collection. Will
return the same Iterator if this instance is already an Iterator.

Note: will not terminate for infinite-sized collections.

* returns
  * an Iterator containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toList: List[(A, B)]`                                               ###

Converts this traversable collection to a list.

Note: will not terminate for infinite-sized collections.

* returns
  * a list containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toMap[T, U](implicit ev: <:<[(A, B), (T, U)]): immutable.Map[T, U]` ###

[use case]

Converts this map to a map. This method is unavailable unless the elements are
members of Tuple2, each ((T, U)) becoming a key-value pair in the map. Duplicate
keys will be overwritten by later keys: if this is an unordered collection,
which key is in the resulting map is undefined.

* returns
  * a map of type `immutable.Map[T, U]` containing all key/value pairs of type
     `(T, U)` of this map.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toSeq: Seq[(A, B)]`                                                 ###

Converts this traversable collection to a sequence. As with `toIterable` , it's
lazy in this default implementation, as this `TraversableOnce` may be lazy and
unevaluated.

Note: will not terminate for infinite-sized collections.

* returns
  * a sequence containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toSet[B >: (A, B)]: immutable.Set[B]`                               ###

Converts this traversable collection to a set.

Note: will not terminate for infinite-sized collections.

* returns
  * a set containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableOnce → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toStream: Stream[(A, B)]`                                           ###

Converts this traversable collection to a stream.

* returns
  * a stream containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


### `def toTraversable: Traversable[(A, B)]`                                 ###

Converts this traversable collection to an unspecified Traversable. Will return
the same collection if this instance is already Traversable.

Note: will not terminate for infinite-sized collections.

* returns
  * a Traversable containing all elements of this traversable collection.

* Definition Classes
  * TraversableProxyLike → TraversableLike → TraversableOnce →
    GenTraversableOnce

(defined at scala.collection.TraversableProxyLike)


--------------------------------------------------------------------------------
       Concrete Value Members From scala.collection.generic.Subtractable
--------------------------------------------------------------------------------


### `def -(elem1: A, elem2: A, elems: A*): This`                             ###

Creates a new collection from this collection with some elements removed.

This method takes two or more elements to be removed. Another overloaded variant
of this method handles the case where a single element is removed.

* elem1
  * the first element to remove.
* elem2
  * the second element to remove.
* elems
  * the remaining elements to remove.
* returns
  * a new collection that contains all elements of the current collection except
    one less occurrence of each of the given elements.

* Definition Classes
  * Subtractable

(defined at scala.collection.generic.Subtractable)


### `def --(xs: GenTraversableOnce[A]): This`                                ###

Creates a new collection from this collection by removing all elements of
another collection.

* xs
  * the collection containing the removed elements.
* returns
  * a new collection that contains all elements of the current collection except
    one less occurrence of each of the elements of `elems` .

* Definition Classes
  * Subtractable

(defined at scala.collection.generic.Subtractable)


--------------------------------------------------------------------------------
Concrete Value Members From Implicit scala.collection.parallel.CollectionsHaveToParArray
--------------------------------------------------------------------------------


### `def toParArray: ParArray[T]`                                            ###

* Implicit information
  * This member is added by an implicit conversion from MapProxyLike [A, B, This]
    to CollectionsHaveToParArray [MapProxyLike [A, B, This], T] performed by
    method CollectionsHaveToParArray in scala.collection.parallel. This
    conversion will take place only if an implicit value of type (MapProxyLike [
    A, B, This]) ⇒ GenTraversableOnce [T] is in scope.
* Definition Classes
  * CollectionsHaveToParArray
(added by implicit convertion: scala.collection.parallel.CollectionsHaveToParArray)
