
#                   scala.collection.generic.AtomicIndexFlag                   #

```
trait AtomicIndexFlag extends Signalling
```

A mixin trait that implements index flag behaviour using atomic integers. The
 `setIndex` operation is wait-free, while conditional set operations
 `setIndexIfGreater` and `setIndexIfLesser` are lock-free and support only
monotonic changes.

* Source
  * [Signalling.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/collection/generic/Signalling.scala#L1)


--------------------------------------------------------------------------------
      Concrete Value Members From scala.collection.generic.AtomicIndexFlag
--------------------------------------------------------------------------------


### `def indexFlag: Int`                                                     ###

Returns the value of the index flag.

The index flag holds an integer which carries some operation-specific meaning.
For instance, `takeWhile` operation sets the index flag to the position of the
element where the predicate fails. Other workers may check this index against
the indices they are working on and return if this index is smaller than their
index. Examples of operations using this are `takeWhile` , `dropWhile` , `span`
and `indexOf` .

* returns
  * the value of the index flag

* Definition Classes
  * AtomicIndexFlag → Signalling

(defined at scala.collection.generic.AtomicIndexFlag)


### `def setIndexFlag(f: Int): Unit`                                         ###

Sets the value of the index flag.

The index flag holds an integer which carries some operation-specific meaning.
For instance, `takeWhile` operation sets the index flag to the position of the
element where the predicate fails. Other workers may check this index against
the indices they are working on and return if this index is smaller than their
index. Examples of operations using this are `takeWhile` , `dropWhile` , `span`
and `indexOf` .

* f
  * the value to which the index flag is set.

* Definition Classes
  * AtomicIndexFlag → Signalling

(defined at scala.collection.generic.AtomicIndexFlag)


### `def setIndexFlagIfGreater(f: Int): Unit`                                ###

Sets the value of the index flag if argument is greater than current value. This
method does this atomically.

The index flag holds an integer which carries some operation-specific meaning.
For instance, `takeWhile` operation sets the index flag to the position of the
element where the predicate fails. Other workers may check this index against
the indices they are working on and return if this index is smaller than their
index. Examples of operations using this are `takeWhile` , `dropWhile` , `span`
and `indexOf` .

* f
  * the value to which the index flag is set

* Definition Classes
  * AtomicIndexFlag → Signalling

(defined at scala.collection.generic.AtomicIndexFlag)


### `def setIndexFlagIfLesser(f: Int): Unit`                                 ###

Sets the value of the index flag if argument is lesser than current value. This
method does this atomically.

The index flag holds an integer which carries some operation-specific meaning.
For instance, `takeWhile` operation sets the index flag to the position of the
element where the predicate fails. Other workers may check this index against
the indices they are working on and return if this index is smaller than their
index. Examples of operations using this are `takeWhile` , `dropWhile` , `span`
and `indexOf` .

* f
  * the value to which the index flag is set

* Definition Classes
  * AtomicIndexFlag → Signalling

(defined at scala.collection.generic.AtomicIndexFlag)


--------------------------------------------------------------------------------
        Abstract Value Members From scala.collection.generic.Signalling
--------------------------------------------------------------------------------


### `abstract def abort(): Unit`                                             ###

Sends an abort signal to other workers.

Abort flag being true means that a worker can abort and produce whatever result,
since its result will not affect the final result of computation. An example of
operations using this are `find` , `forall` and `exists` methods.

* Definition Classes
  * Signalling

(defined at scala.collection.generic.Signalling)


### `abstract def isAborted: Boolean`                                        ###

Checks whether an abort signal has been issued.

Abort flag being true means that a worker can abort and produce whatever result,
since its result will not affect the final result of computation. An example of
operations using this are `find` , `forall` and `exists` methods.

* returns
  * the state of the abort

* Definition Classes
  * Signalling

(defined at scala.collection.generic.Signalling)


### `abstract def tag: Int`                                                  ###

A read only tag specific to the signalling object. It is used to give specific
workers information on the part of the collection being operated on.

* Definition Classes
  * Signalling
(defined at scala.collection.generic.Signalling)
