
#                     scala.collection.mutable.SetBuilder                     #

```
class SetBuilder[A, Coll <: collection.Set[A] with collection.SetLike[A, Coll]] extends Builder[A, Coll]
```

The canonical builder for mutable Sets.

* A
  * The type of the elements that will be contained in this set.
* Coll
  * The type of the actual collection this set builds.

* Source
  * [SetBuilder.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/collection/mutable/SetBuilder.scala#L1)
* Since
  * 2.8


--------------------------------------------------------------------------------
              Value Members From scala.collection.generic.Growable
--------------------------------------------------------------------------------


### `def ++=(xs: TraversableOnce[A]): SetBuilder.this.type`                  ###

adds all elements produced by a TraversableOnce to this growable collection.

* xs
  * the TraversableOnce producing the elements to add.
* returns
  * the growable collection itself.

* Definition Classes
  * Growable

(defined at scala.collection.generic.Growable)


### `def +=(elem1: A, elem2: A, elems: A*): SetBuilder.this.type`            ###

adds two or more elements to this growable collection.

* elem1
  * the first element to add.
* elem2
  * the second element to add.
* elems
  * the remaining elements to add.
* returns
  * the growable collection itself

* Definition Classes
  * Growable

(defined at scala.collection.generic.Growable)


--------------------------------------------------------------------------------
              Value Members From scala.collection.mutable.Builder
--------------------------------------------------------------------------------


### `def mapResult[NewTo](f: (Coll) ⇒ NewTo): Builder[A, NewTo]`             ###

Creates a new builder by applying a transformation function to the results of
this builder.

* NewTo
  * the type of collection returned by `f` .
* f
  * the transformation function.
* returns
  * a new builder which is the same as the current builder except that a
    transformation function is applied to this builder's result.

* Definition Classes
  * Builder

(defined at scala.collection.mutable.Builder)


### `def sizeHint(size: Int): Unit`                                          ###

Gives a hint how many elements are expected to be added when the next `result`
is called. Some builder classes will optimize their representation based on the
hint. However, builder implementations are still required to work correctly even
if the hint is wrong, i.e. a different number of elements is added.

* size
  * the hint how many elements will be added.

* Definition Classes
  * Builder

(defined at scala.collection.mutable.Builder)


### `def sizeHint(coll: TraversableLike[_, _]): Unit`                        ###

Gives a hint that one expects the `result` of this builder to have the same size
as the given collection, plus some delta. This will provide a hint only if the
collection is known to have a cheap `size` method. Currently this is assumed to
be the case if and only if the collection is of type `IndexedSeqLike` . Some
builder classes will optimize their representation based on the hint. However,
builder implementations are still required to work correctly even if the hint is
wrong, i.e. a different number of elements is added.

* coll
  * the collection which serves as a hint for the result's size.

* Definition Classes
  * Builder

(defined at scala.collection.mutable.Builder)


### `def sizeHint(coll: TraversableLike[_, _], delta: Int): Unit`            ###

Gives a hint that one expects the `result` of this builder to have the same size
as the given collection, plus some delta. This will provide a hint only if the
collection is known to have a cheap `size` method. Currently this is assumed to
be the case if and only if the collection is of type `IndexedSeqLike` . Some
builder classes will optimize their representation based on the hint. However,
builder implementations are still required to work correctly even if the hint is
wrong, i.e. a different number of elements is added.

* coll
  * the collection which serves as a hint for the result's size.
* delta
  * a correction to add to the `coll.size` to produce the size hint.

* Definition Classes
  * Builder

(defined at scala.collection.mutable.Builder)


### `def sizeHintBounded(size: Int, boundingColl: TraversableLike[_, _]): Unit` ###

Gives a hint how many elements are expected to be added when the next `result`
is called, together with an upper bound given by the size of some other
collection. Some builder classes will optimize their representation based on the
hint. However, builder implementations are still required to work correctly even
if the hint is wrong, i.e. a different number of elements is added.

* size
  * the hint how many elements will be added.
* boundingColl
  * the bounding collection. If it is an IndexedSeqLike, then sizes larger than
    collection's size are reduced.

* Definition Classes
  * Builder

(defined at scala.collection.mutable.Builder)


--------------------------------------------------------------------------------
         Instance Constructors From scala.collection.mutable.SetBuilder
--------------------------------------------------------------------------------


### `new SetBuilder(empty: Coll)`                                            ###

* empty
  * The empty element of the collection.

(defined at scala.collection.mutable.SetBuilder)


--------------------------------------------------------------------------------
             Value Members From scala.collection.mutable.SetBuilder
--------------------------------------------------------------------------------


### `def +=(x: A): SetBuilder.this.type`                                     ###

Adds a single element to the builder.

* returns
  * the builder itself.

* Definition Classes
  * SetBuilder → Builder → Growable

(defined at scala.collection.mutable.SetBuilder)


### `def clear(): Unit`                                                      ###

Clears the contents of this builder. After execution of this method the builder
will contain no elements.

* Definition Classes
  * SetBuilder → Builder → Growable → Clearable

(defined at scala.collection.mutable.SetBuilder)


### `var elems: Coll`                                                        ###

* Attributes
  * protected

(defined at scala.collection.mutable.SetBuilder)


### `def result(): Coll`                                                     ###

Produces a collection from the added elements. The builder's contents are
undefined after this operation.

* returns
  * a collection containing the elements added to this builder.

* Definition Classes
  * SetBuilder → Builder

(defined at scala.collection.mutable.SetBuilder)


--------------------------------------------------------------------------------
Value Members From Implicit scala.collection.parallel.CollectionsHaveToParArray
--------------------------------------------------------------------------------


### `def toParArray: ParArray[T]`                                            ###

* Implicit information
  * This member is added by an implicit conversion from SetBuilder [A, Coll] to
    CollectionsHaveToParArray [SetBuilder [A, Coll], T] performed by method
    CollectionsHaveToParArray in scala.collection.parallel. This conversion will
    take place only if an implicit value of type (SetBuilder [A, Coll]) ⇒
    GenTraversableOnce [T] is in scope.
* Definition Classes
  * CollectionsHaveToParArray
(added by implicit convertion: scala.collection.parallel.CollectionsHaveToParArray)
