
#                       scala.concurrent.DelayedLazyVal                       #

```
class DelayedLazyVal[T] extends AnyRef
```

A `DelayedLazyVal` is a wrapper for lengthy computations which have a valid
partially computed result.

The first argument is a function for obtaining the result at any given point in
time, and the second is the lengthy computation. Once the computation is
complete, the `apply` method will stop recalculating it and return a fixed value
from that point forward.

* Source
  * [DelayedLazyVal.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/concurrent/DelayedLazyVal.scala#L1)
* Version
  * 2.8


--------------------------------------------------------------------------------
           Instance Constructors From scala.concurrent.DelayedLazyVal
--------------------------------------------------------------------------------


### `new DelayedLazyVal(f: () ⇒ T, body: ⇒ Unit)(implicit exec: ExecutionContext)` ###

* f
  * the function to obtain the current value at any point in time
* body
  * the computation to run to completion in another thread

(defined at scala.concurrent.DelayedLazyVal)


--------------------------------------------------------------------------------
               Value Members From scala.concurrent.DelayedLazyVal
--------------------------------------------------------------------------------


### `def apply(): T`                                                         ###

The current result of f(), or the final result if complete.

* returns
  * the current value

(defined at scala.concurrent.DelayedLazyVal)


### `def isDone: Boolean`                                                    ###

Whether the computation is complete.

* returns
  * true if the computation is complete.
(defined at scala.concurrent.DelayedLazyVal)
