
#                           scala.concurrent.Future                           #

```
object Future
```

Future companion object.

* Source
  * [Future.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/concurrent/Future.scala#L1)


--------------------------------------------------------------------------------
                   Value Members From scala.concurrent.Future
--------------------------------------------------------------------------------


### `def apply[T](body: ⇒ T)(implicit executor: ExecutionContext): Future[T]` ###

Starts an asynchronous computation and returns a `Future` object with the result
of that computation.

The result becomes available once the asynchronous computation is completed.

* T
  * the type of the result
* body
  * the asychronous computation
* executor
  * the execution context on which the future is run
* returns
  * the `Future` holding the result of the computation

(defined at scala.concurrent.Future)


### `def failed[T](exception: Throwable): Future[T]`                         ###

Creates an already completed Future with the specified exception.

* T
  * the type of the value in the future
* returns
  * the newly created `Future` object

(defined at scala.concurrent.Future)


### `def find[T](futures: TraversableOnce[Future[T]])(p: (T) ⇒ Boolean)(implicit executor: ExecutionContext): Future[Option[T]]` ###

Returns a `Future` that will hold the optional result of the first `Future` with
a result that matches the predicate.

(defined at scala.concurrent.Future)


### `def firstCompletedOf[T](futures: TraversableOnce[Future[T]])(implicit executor: ExecutionContext): Future[T]` ###

Returns a new `Future` to the result of the first future in the list that is
completed.

(defined at scala.concurrent.Future)


### `def fold[T, R](futures: TraversableOnce[Future[T]])(zero: R)(op: (R, T) ⇒ R)(implicit executor: ExecutionContext): Future[R]` ###

A non-blocking fold over the specified futures, with the start value of the
given zero. The fold is performed on the thread where the last future is
completed, the result will be the first failure of any of the futures, or any
failure in the actual fold, or the result of the fold.

Example:

```scala
val result = Await.result(Future.fold(futures)(0)(_ + _), 5 seconds)
```

(defined at scala.concurrent.Future)


### `def fromTry[T](result: Try[T]): Future[T]`                              ###

Creates an already completed Future with the specified result or exception.

* T
  * the type of the value in the promise
* returns
  * the newly created `Future` object

(defined at scala.concurrent.Future)


### `def reduce[T, R >: T](futures: TraversableOnce[Future[T]])(op: (R, T) ⇒ R)(implicit executor: ExecutionContext): Future[R]` ###

Initiates a fold over the supplied futures where the fold-zero is the result
value of the `Future` that's completed first.

Example:

```scala
val result = Await.result(Future.reduce(futures)(_ + _), 5 seconds)
```

(defined at scala.concurrent.Future)


### `def sequence[A, M[X] <: TraversableOnce[X]](in: M[Future[A]])(implicit cbf: CanBuildFrom[M[Future[A]], A, M[A]], executor: ExecutionContext): Future[M[A]]` ###

Simple version of `Future.traverse` . Transforms a `TraversableOnce[Future[A]]`
into a `Future[TraversableOnce[A]]` . Useful for reducing many `Future` s into a
single `Future` .

(defined at scala.concurrent.Future)


### `def successful[T](result: T): Future[T]`                                ###

Creates an already completed Future with the specified result.

* T
  * the type of the value in the future
* returns
  * the newly created `Future` object

(defined at scala.concurrent.Future)


### `def traverse[A, B, M[X] <: TraversableOnce[X]](in: M[A])(fn: (A) ⇒ Future[B])(implicit cbf: CanBuildFrom[M[A], B, M[B]], executor: ExecutionContext): Future[M[B]]` ###

Transforms a `TraversableOnce[A]` into a `Future[TraversableOnce[B]]` using the
provided function `A => Future[B]` . This is useful for performing a parallel
map. For example, to apply a function to all items of a list in parallel:

```scala
val myFutureList = Future.traverse(myList)(x => Future(myFunc(x)))
```
(defined at scala.concurrent.Future)
