
#                           scala.concurrent.SyncVar                           #

```
class SyncVar[A] extends AnyRef
```

A class to provide safe concurrent access to a mutable cell. All methods are
synchronized.

* A
  * type of the contained value

* Source
  * [SyncVar.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/concurrent/SyncVar.scala#L1)
* Version
  * 1.0, 10/03/2003


--------------------------------------------------------------------------------
             Deprecated Value Members From scala.concurrent.SyncVar
--------------------------------------------------------------------------------


### `def set(x: A): Unit`                                                    ###

* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.10.0)_ Use `put` instead, as `set` is potentionally
    error-prone

(defined at scala.concurrent.SyncVar)


### `def unset(): Unit`                                                      ###

* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.10.0)_ Use `take` instead, as `unset` is potentionally
    error-prone

(defined at scala.concurrent.SyncVar)


--------------------------------------------------------------------------------
              Instance Constructors From scala.concurrent.SyncVar
--------------------------------------------------------------------------------


### `new SyncVar()`                                                          ###

(defined at scala.concurrent.SyncVar)


--------------------------------------------------------------------------------
                  Value Members From scala.concurrent.SyncVar
--------------------------------------------------------------------------------


### `def get(timeout: Long): Option[A]`                                      ###

Waits for this SyncVar to become defined at least for `timeout` milliseconds
(possibly more), and gets its value.

* timeout
  * the amount of milliseconds to wait, 0 means forever
* returns
  * `None` if variable is undefined after `timeout` , `Some(value)` otherwise

(defined at scala.concurrent.SyncVar)


### `def get: A`                                                             ###

Waits for this SyncVar to become defined and returns the result, without
modifying the stored value.

* returns
  * value that is held in this container

(defined at scala.concurrent.SyncVar)


### `def isSet: Boolean`                                                     ###

Checks whether a value is stored in the synchronized variable

(defined at scala.concurrent.SyncVar)


### `def put(x: A): Unit`                                                    ###

Places a value in the SyncVar. If the SyncVar already has a stored value, it
waits until another thread takes it

(defined at scala.concurrent.SyncVar)


### `def take(): A`                                                          ###

Waits for this SyncVar to become defined and returns the result, unsetting the
stored value before returning.

* returns
  * value that was held in this container

(defined at scala.concurrent.SyncVar)


### `def take(timeout: Long): A`                                             ###

Waits for this SyncVar to become defined at least for `timeout` milliseconds
(possibly more), and takes its value by first reading and then removing the
value from the SyncVar.

* timeout
  * the amount of milliseconds to wait, 0 means forever
* returns
  * the value or a throws an exception if the timeout occurs

* Exceptions thrown
  * NoSuchElementException on timeout
(defined at scala.concurrent.SyncVar)
