
#                                scala.io.StdIn                                #

```
object StdIn extends StdIn
```

* Source
  * [StdIn.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/io/StdIn.scala#L1)


--------------------------------------------------------------------------------
                       Value Members From scala.io.StdIn
--------------------------------------------------------------------------------


### `def readBoolean(): Boolean`                                             ###

Reads a boolean value from an entire line of the default input. Has a fairly
liberal interpretation of the input.

* returns
  * the boolean value read, or false if it couldn't be converted to a boolean

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.

(defined at scala.io.StdIn)


### `def readByte(): Byte`                                                   ###

Reads a byte value from an entire line of the default input.

* returns
  * the Byte that was read

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to a
    Byte

(defined at scala.io.StdIn)


### `def readChar(): Char`                                                   ###

Reads a char value from an entire line of the default input.

* returns
  * the Char that was read

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.StringIndexOutOfBoundsException` if the line read from default
    input was empty

(defined at scala.io.StdIn)


### `def readDouble(): Double`                                               ###

Reads a double value from an entire line of the default input.

* returns
  * the Double that was read.

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to a
    Float

(defined at scala.io.StdIn)


### `def readFloat(): Float`                                                 ###

Reads a float value from an entire line of the default input.

* returns
  * the Float that was read.

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to a
    Float

(defined at scala.io.StdIn)


### `def readInt(): Int`                                                     ###

Reads an int value from an entire line of the default input.

* returns
  * the Int that was read

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to an
    Int

(defined at scala.io.StdIn)


### `def readLine(): String`                                                 ###

Read a full line from the default input. Returns `null` if the end of the input
stream has been reached.

* returns
  * the string read from the terminal or null if the end of stream was reached.

* Definition Classes
  * StdIn

(defined at scala.io.StdIn)


### `def readLine(text: String, args: Any*): String`                         ###

Print and flush formatted text to the default output, and read a full line from
the default input. Returns `null` if the end of the input stream has been
reached.

* text
  * the format of the text to print out, as in `printf` .
* args
  * the parameters used to instantiate the format, as in `printf` .
* returns
  * the string read from the default input

* Definition Classes
  * StdIn

(defined at scala.io.StdIn)


### `def readLong(): Long`                                                   ###

Reads an long value from an entire line of the default input.

* returns
  * the Long that was read

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to a
    Long

(defined at scala.io.StdIn)


### `def readShort(): Short`                                                 ###

Reads a short value from an entire line of the default input.

* returns
  * the short that was read

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.
     `java.lang.NumberFormatException` if the value couldn't be converted to a
    Short

(defined at scala.io.StdIn)


### `def readf(format: String): List[Any]`                                   ###

Reads in some structured input (from the default input), specified by a format
specifier. See class `java.text.MessageFormat` for details of the format
specification.

* format
  * the format of the input.
* returns
  * a list of all extracted values.

* Definition Classes
  * StdIn
* Exceptions thrown
  * `java.io.EOFException` if the end of the input stream has been reached.

(defined at scala.io.StdIn)


### `def readf1(format: String): Any`                                        ###

Reads in some structured input (from the default input), specified by a format
specifier, returning only the first value extracted, according to the format
specification.

* format
  * format string, as accepted by `readf` .
* returns
  * The first value that was extracted from the input

* Definition Classes
  * StdIn

(defined at scala.io.StdIn)


### `def readf2(format: String): (Any, Any)`                                 ###

Reads in some structured input (from the default input), specified by a format
specifier, returning only the first two values extracted, according to the
format specification.

* format
  * format string, as accepted by `readf` .
* returns
  * A scala.Tuple2 containing the first two values extracted

* Definition Classes
  * StdIn

(defined at scala.io.StdIn)


### `def readf3(format: String): (Any, Any, Any)`                            ###

Reads in some structured input (from the default input), specified by a format
specifier, returning only the first three values extracted, according to the
format specification.

* format
  * format string, as accepted by `readf` .
* returns
  * A scala.Tuple3 containing the first three values extracted

* Definition Classes
  * StdIn
(defined at scala.io.StdIn)
