
#                    scala.math.ScalaNumericAnyConversions                    #

```
trait ScalaNumericAnyConversions extends Any
```

Conversions which present a consistent conversion interface across all the
numeric types, suitable for use in value classes.

* Source
  * [ScalaNumericConversions.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/math/ScalaNumericConversions.scala#L1)


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
       Abstract Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `abstract def byteValue(): Byte`                                         ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def doubleValue(): Double`                                     ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def floatValue(): Float`                                       ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def intValue(): Int`                                           ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def isWhole(): Boolean`                                        ###

* returns
  * `true` if this number has no decimal component, `false` otherwise.

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def longValue(): Long`                                         ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def shortValue(): Short`                                       ###

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def underlying(): Any`                                         ###

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
       Concrete Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `def isValidByte: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Byte MinValue and MaxValue; otherwise returns `false` .

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidChar: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Char MinValue and MaxValue; otherwise returns `false` .

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidInt: Boolean`                                                ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Int MinValue and MaxValue; otherwise returns `false` .

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidShort: Boolean`                                              ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Short MinValue and MaxValue; otherwise returns `false` .

(defined at scala.math.ScalaNumericAnyConversions)


### `def toByte: Byte`                                                       ###

Returns the value of this as a scala.Byte. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toChar: Char`                                                       ###

Returns the value of this as a scala.Char. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toDouble: Double`                                                   ###

Returns the value of this as a scala.Double. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toFloat: Float`                                                     ###

Returns the value of this as a scala.Float. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toInt: Int`                                                         ###

Returns the value of this as an scala.Int. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toLong: Long`                                                       ###

Returns the value of this as a scala.Long. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def toShort: Short`                                                     ###

Returns the value of this as a scala.Short. This may involve rounding or
truncation.

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveEquals(x: Any): Boolean`                            ###

Should only be called after all known non-primitive types have been excluded.
This method won't dispatch anywhere else after checking against the primitives
to avoid infinite recursion between equals and this on unknown "Number"
variants.

Additionally, this should only be called if the numeric type is happy to be
converted to Long, Float, and Double. If for instance a BigInt much larger than
the Long range is sent here, it will claim equality with whatever Long is left
in its lower 64 bits. Or a BigDecimal with more precision than Double can hold:
same thing. There's no way given the interface available here to prevent this
error.

* Attributes
  * protected

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveHashcode(): Int`                                    ###

* Attributes
  * protected
(defined at scala.math.ScalaNumericAnyConversions)
