
#                      scala.math.ScalaNumericConversions                      #

```
trait ScalaNumericConversions extends ScalaNumber with ScalaNumericAnyConversions
```

A slightly more specific conversion trait for classes which extend ScalaNumber
(which excludes value classes.)

* Source
  * [ScalaNumericConversions.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/math/ScalaNumericConversions.scala#L1)


--------------------------------------------------------------------------------
                  Concrete Value Members From java.lang.Number
--------------------------------------------------------------------------------


### `def byteValue(): Byte`                                                  ###

* Definition Classes
  * Number

(defined at java.lang.Number)


### `def shortValue(): Short`                                                ###

* Definition Classes
  * Number

(defined at java.lang.Number)


--------------------------------------------------------------------------------
       Abstract Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `abstract def doubleValue(): Double`                                     ###

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def floatValue(): Float`                                       ###

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def intValue(): Int`                                           ###

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def isWhole(): Boolean`                                        ###

* returns
  * `true` if this number has no decimal component, `false` otherwise.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `abstract def longValue(): Long`                                         ###

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
       Concrete Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `def isValidByte: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Byte MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidChar: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Char MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidInt: Boolean`                                                ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Int MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidShort: Boolean`                                              ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Short MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toByte: Byte`                                                       ###

Returns the value of this as a scala.Byte. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toChar: Char`                                                       ###

Returns the value of this as a scala.Char. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toDouble: Double`                                                   ###

Returns the value of this as a scala.Double. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toFloat: Float`                                                     ###

Returns the value of this as a scala.Float. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toInt: Int`                                                         ###

Returns the value of this as an scala.Int. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toLong: Long`                                                       ###

Returns the value of this as a scala.Long. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toShort: Short`                                                     ###

Returns the value of this as a scala.Short. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveEquals(x: Any): Boolean`                            ###

Should only be called after all known non-primitive types have been excluded.
This method won't dispatch anywhere else after checking against the primitives
to avoid infinite recursion between equals and this on unknown "Number"
variants.

Additionally, this should only be called if the numeric type is happy to be
converted to Long, Float, and Double. If for instance a BigInt much larger than
the Long range is sent here, it will claim equality with whatever Long is left
in its lower 64 bits. Or a BigDecimal with more precision than Double can hold:
same thing. There's no way given the interface available here to prevent this
error.

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveHashcode(): Int`                                    ###

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
         Abstract Value Members From scala.math.ScalaNumericConversions
--------------------------------------------------------------------------------


### `abstract def underlying(): AnyRef`                                      ###

* Definition Classes
  * ScalaNumericConversions → ScalaNumericAnyConversions → ScalaNumber
(defined at scala.math.ScalaNumericConversions)
