
#                           scala.ref.SoftReference                           #

```
class SoftReference[+T <: AnyRef] extends ReferenceWrapper[T]
```

* Source
  * [SoftReference.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/ref/SoftReference.scala#L1)


--------------------------------------------------------------------------------
                         Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def equals(that: Any): Boolean`                                         ###

Compares the receiver object ( `this` ) with the argument object ( `that` ) for
equivalence.

Any implementation of this method should be an
[equivalence relation](http://en.wikipedia.org/wiki/Equivalence_relation) :

* It is reflexive: for any instance `x` of type `Any` , `x.equals(x)` should
   return `true` .
* It is symmetric: for any instances `x` and `y` of type `Any` , `x.equals(y)`
   should return `true` if and only if `y.equals(x)` returns `true` .
* It is transitive: for any instances `x` , `y` , and `z` of type `AnyRef` if
    `x.equals(y)` returns `true` and `y.equals(z)` returns `true` , then
    `x.equals(z)` should return `true` .

If you override this method, you should verify that your implementation remains
an equivalence relation. Additionally, when overriding this method it is usually
necessary to override `hashCode` to ensure that objects which are "equal" (
 `o1.equals(o2)` returns `true` ) hash to the same scala.Int. (
 `o1.hashCode.equals(o2.hashCode)` ).

* that
  * the object to compare against this object for equality.
* returns
  * `true` if the receiver object is equivalent to the argument; `false`
    otherwise.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def hashCode(): Int`                                                    ###

Calculate a hash code value for the object.

The default hashing algorithm is platform dependent.

Note that it is allowed for two objects to have identical hash codes (
 `o1.hashCode.equals(o2.hashCode)` ) yet not be equal ( `o1.equals(o2)` returns
 `false` ). A degenerate implementation could always return `0` . However, it is
required that if two objects are equal ( `o1.equals(o2)` returns `true` ) that
they have identical hash codes ( `o1.hashCode.equals(o2.hashCode)` ). Therefore,
when overriding this method, be sure to verify that the behavior is consistent
with the `equals` method.

* returns
  * the hash code value for this object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


--------------------------------------------------------------------------------
                 Value Members From scala.ref.ReferenceWrapper
--------------------------------------------------------------------------------


### `def apply(): T`                                                         ###

return the underlying value

* returns
  * the result of function application.

* Definition Classes
  * ReferenceWrapper → Reference → Function0

(defined at scala.ref.ReferenceWrapper)


### `def clear(): Unit`                                                      ###

* Definition Classes
  * ReferenceWrapper → Reference

(defined at scala.ref.ReferenceWrapper)


### `def enqueue(): Boolean`                                                 ###

* Definition Classes
  * ReferenceWrapper → Reference

(defined at scala.ref.ReferenceWrapper)


### `def get: Option[T]`                                                     ###

return `Some` underlying if it hasn't been collected, otherwise `None`

* Definition Classes
  * ReferenceWrapper → Reference

(defined at scala.ref.ReferenceWrapper)


### `def isEnqueued(): Boolean`                                              ###

* Definition Classes
  * ReferenceWrapper → Reference

(defined at scala.ref.ReferenceWrapper)


### `def self: java.lang.ref.Reference[_ <: T]`                              ###

* Definition Classes
  * ReferenceWrapper → Proxy

(defined at scala.ref.ReferenceWrapper)


--------------------------------------------------------------------------------
               Instance Constructors From scala.ref.SoftReference
--------------------------------------------------------------------------------


### `new SoftReference(value: T)`                                            ###

(defined at scala.ref.SoftReference)


--------------------------------------------------------------------------------
                   Value Members From scala.ref.SoftReference
--------------------------------------------------------------------------------


### `val underlying: java.lang.ref.SoftReference[_ <: T]`                    ###

* Definition Classes
  * SoftReference → ReferenceWrapper
(defined at scala.ref.SoftReference)
