
#                            scala.runtime.RichChar                            #

```
final class RichChar extends AnyVal with IntegralProxy[Char]
```

* Source
  * [RichChar.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/runtime/RichChar.scala#L1)


--------------------------------------------------------------------------------
                                  Type Members
--------------------------------------------------------------------------------


### `type ResultWithoutStep = NumericRange[Char]`                            ###

* Definition Classes
  * IntegralProxy → RangedProxy


--------------------------------------------------------------------------------
                        Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                        Value Members From scala.AnyVal
--------------------------------------------------------------------------------


### `def getClass(): Class[_ <: AnyVal]`                                     ###

Returns the runtime class representation of the object.

* returns
  * a class object corresponding to the runtime type of the receiver.

* Definition Classes
  * AnyVal → Any

(defined at scala.AnyVal)


--------------------------------------------------------------------------------
                         Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


--------------------------------------------------------------------------------
                     Value Members From scala.math.Ordered
--------------------------------------------------------------------------------


### `def <(that: Char): Boolean`                                             ###

Returns true if `this` is less than `that`

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def <=(that: Char): Boolean`                                            ###

Returns true if `this` is less than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >(that: Char): Boolean`                                             ###

Returns true if `this` is greater than `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >=(that: Char): Boolean`                                            ###

Returns true if `this` is greater than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def compareTo(that: Char): Int`                                         ###

Result of comparing `this` with operand `that` .

* Definition Classes
  * Ordered → Comparable

(defined at scala.math.Ordered)


--------------------------------------------------------------------------------
            Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `def isValidByte: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Byte MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidInt: Boolean`                                                ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Int MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidShort: Boolean`                                              ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Short MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toByte: Byte`                                                       ###

Returns the value of this as a scala.Byte. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toChar: Char`                                                       ###

Returns the value of this as a scala.Char. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toDouble: Double`                                                   ###

Returns the value of this as a scala.Double. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toFloat: Float`                                                     ###

Returns the value of this as a scala.Float. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toInt: Int`                                                         ###

Returns the value of this as an scala.Int. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toLong: Long`                                                       ###

Returns the value of this as a scala.Long. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toShort: Short`                                                     ###

Returns the value of this as a scala.Short. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveEquals(x: Any): Boolean`                            ###

Should only be called after all known non-primitive types have been excluded.
This method won't dispatch anywhere else after checking against the primitives
to avoid infinite recursion between equals and this on unknown "Number"
variants.

Additionally, this should only be called if the numeric type is happy to be
converted to Long, Float, and Double. If for instance a BigInt much larger than
the Long range is sent here, it will claim equality with whatever Long is left
in its lower 64 bits. Or a BigDecimal with more precision than Double can hold:
same thing. There's no way given the interface available here to prevent this
error.

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveHashcode(): Int`                                    ###

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
                 Value Members From scala.runtime.IntegralProxy
--------------------------------------------------------------------------------


### `def to(end: Char): Inclusive[Char]`                                     ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def to(end: Char, step: Char): Inclusive[Char]`                         ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def until(end: Char): Exclusive[Char]`                                  ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def until(end: Char, step: Char): Exclusive[Char]`                      ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


--------------------------------------------------------------------------------
                 Value Members From scala.runtime.OrderedProxy
--------------------------------------------------------------------------------


### `def compare(y: Char): Int`                                              ###

Result of comparing `this` with operand `that` .

Implement this method to determine how instances of A will be sorted.

Returns `x` where:

*  `x < 0` when `this < that`
*  `x == 0` when `this == that`
*  `x > 0` when `this > that`

* Definition Classes
  * OrderedProxy → Ordered

(defined at scala.runtime.OrderedProxy)


--------------------------------------------------------------------------------
               Instance Constructors From scala.runtime.RichChar
--------------------------------------------------------------------------------


### `new RichChar(self: Char)`                                               ###

(defined at scala.runtime.RichChar)


--------------------------------------------------------------------------------
                   Value Members From scala.runtime.RichChar
--------------------------------------------------------------------------------


### `def abs: Char`                                                          ###

Returns the absolute value of `this` .

* Definition Classes
  * RichChar → ScalaNumberProxy

(defined at scala.runtime.RichChar)


### `def asDigit: Int`                                                       ###

(defined at scala.runtime.RichChar)


### `def byteValue(): Byte`                                                  ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def doubleValue(): Double`                                              ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def floatValue(): Float`                                                ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def getDirectionality: Byte`                                            ###

(defined at scala.runtime.RichChar)


### `def getNumericValue: Int`                                               ###

(defined at scala.runtime.RichChar)


### `def getType: Int`                                                       ###

(defined at scala.runtime.RichChar)


### `def intValue(): Int`                                                    ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def isControl: Boolean`                                                 ###

(defined at scala.runtime.RichChar)


### `def isDigit: Boolean`                                                   ###

(defined at scala.runtime.RichChar)


### `def isHighSurrogate: Boolean`                                           ###

(defined at scala.runtime.RichChar)


### `def isIdentifierIgnorable: Boolean`                                     ###

(defined at scala.runtime.RichChar)


### `def isLetter: Boolean`                                                  ###

(defined at scala.runtime.RichChar)


### `def isLetterOrDigit: Boolean`                                           ###

(defined at scala.runtime.RichChar)


### `def isLowSurrogate: Boolean`                                            ###

(defined at scala.runtime.RichChar)


### `def isLower: Boolean`                                                   ###

(defined at scala.runtime.RichChar)


### `def isMirrored: Boolean`                                                ###

(defined at scala.runtime.RichChar)


### `def isSpaceChar: Boolean`                                               ###

(defined at scala.runtime.RichChar)


### `def isSurrogate: Boolean`                                               ###

(defined at scala.runtime.RichChar)


### `def isTitleCase: Boolean`                                               ###

(defined at scala.runtime.RichChar)


### `def isUnicodeIdentifierPart: Boolean`                                   ###

(defined at scala.runtime.RichChar)


### `def isUnicodeIdentifierStart: Boolean`                                  ###

(defined at scala.runtime.RichChar)


### `def isUpper: Boolean`                                                   ###

(defined at scala.runtime.RichChar)


### `def isValidChar: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Char MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * RichChar → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def isWhitespace: Boolean`                                              ###

(defined at scala.runtime.RichChar)


### `def longValue(): Long`                                                  ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def max(that: Char): Char`                                              ###

Returns `this` if `this > that` or `that` otherwise.

* Definition Classes
  * RichChar → ScalaNumberProxy

(defined at scala.runtime.RichChar)


### `def min(that: Char): Char`                                              ###

Returns `this` if `this < that` or `that` otherwise.

* Definition Classes
  * RichChar → ScalaNumberProxy

(defined at scala.runtime.RichChar)


### `def num: CharIsIntegral.type`                                           ###

* Attributes
  * protected
* Definition Classes
  * RichChar → IntegralProxy → ScalaNumberProxy

(defined at scala.runtime.RichChar)


### `def ord: math.Ordering.Char.type`                                       ###

* Attributes
  * protected
* Definition Classes
  * RichChar → OrderedProxy

(defined at scala.runtime.RichChar)


### `def reverseBytes: Char`                                                 ###

(defined at scala.runtime.RichChar)


### `val self: Char`                                                         ###

* Definition Classes
  * RichChar → Typed → Proxy

(defined at scala.runtime.RichChar)


### `def shortValue(): Short`                                                ###

* Definition Classes
  * RichChar → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichChar)


### `def signum: Int`                                                        ###

Returns the signum of `this` .

* Definition Classes
  * RichChar → ScalaNumberProxy

(defined at scala.runtime.RichChar)


### `def toLower: Char`                                                      ###

(defined at scala.runtime.RichChar)


### `def toTitleCase: Char`                                                  ###

(defined at scala.runtime.RichChar)


### `def toUpper: Char`                                                      ###

(defined at scala.runtime.RichChar)


--------------------------------------------------------------------------------
               Value Members From scala.runtime.ScalaNumberProxy
--------------------------------------------------------------------------------


### `def underlying(): AnyRef`                                               ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


--------------------------------------------------------------------------------
             Value Members From scala.runtime.ScalaWholeNumberProxy
--------------------------------------------------------------------------------


### `def isWhole(): Boolean`                                                 ###

* returns
  * `true` if this number has no decimal component, `false` otherwise.

* Definition Classes
  * ScalaWholeNumberProxy → ScalaNumericAnyConversions
(defined at scala.runtime.ScalaWholeNumberProxy)
