
#                            scala.runtime.RichLong                            #

```
final class RichLong extends AnyVal with IntegralProxy[Long]
```

* Source
  * [RichLong.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/runtime/RichLong.scala#L1)


--------------------------------------------------------------------------------
                                  Type Members
--------------------------------------------------------------------------------


### `type ResultWithoutStep = NumericRange[Long]`                            ###

* Definition Classes
  * IntegralProxy → RangedProxy


--------------------------------------------------------------------------------
                        Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                        Value Members From scala.AnyVal
--------------------------------------------------------------------------------


### `def getClass(): Class[_ <: AnyVal]`                                     ###

Returns the runtime class representation of the object.

* returns
  * a class object corresponding to the runtime type of the receiver.

* Definition Classes
  * AnyVal → Any

(defined at scala.AnyVal)


--------------------------------------------------------------------------------
                         Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


--------------------------------------------------------------------------------
                     Value Members From scala.math.Ordered
--------------------------------------------------------------------------------


### `def <(that: Long): Boolean`                                             ###

Returns true if `this` is less than `that`

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def <=(that: Long): Boolean`                                            ###

Returns true if `this` is less than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >(that: Long): Boolean`                                             ###

Returns true if `this` is greater than `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >=(that: Long): Boolean`                                            ###

Returns true if `this` is greater than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def compareTo(that: Long): Int`                                         ###

Result of comparing `this` with operand `that` .

* Definition Classes
  * Ordered → Comparable

(defined at scala.math.Ordered)


--------------------------------------------------------------------------------
            Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `def toByte: Byte`                                                       ###

Returns the value of this as a scala.Byte. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toChar: Char`                                                       ###

Returns the value of this as a scala.Char. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toDouble: Double`                                                   ###

Returns the value of this as a scala.Double. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toFloat: Float`                                                     ###

Returns the value of this as a scala.Float. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toInt: Int`                                                         ###

Returns the value of this as an scala.Int. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toLong: Long`                                                       ###

Returns the value of this as a scala.Long. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toShort: Short`                                                     ###

Returns the value of this as a scala.Short. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveEquals(x: Any): Boolean`                            ###

Should only be called after all known non-primitive types have been excluded.
This method won't dispatch anywhere else after checking against the primitives
to avoid infinite recursion between equals and this on unknown "Number"
variants.

Additionally, this should only be called if the numeric type is happy to be
converted to Long, Float, and Double. If for instance a BigInt much larger than
the Long range is sent here, it will claim equality with whatever Long is left
in its lower 64 bits. Or a BigDecimal with more precision than Double can hold:
same thing. There's no way given the interface available here to prevent this
error.

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveHashcode(): Int`                                    ###

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
                 Value Members From scala.runtime.IntegralProxy
--------------------------------------------------------------------------------


### `def to(end: Long): Inclusive[Long]`                                     ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def to(end: Long, step: Long): Inclusive[Long]`                         ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def until(end: Long): Exclusive[Long]`                                  ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


### `def until(end: Long, step: Long): Exclusive[Long]`                      ###

* Definition Classes
  * IntegralProxy → RangedProxy

(defined at scala.runtime.IntegralProxy)


--------------------------------------------------------------------------------
                 Value Members From scala.runtime.OrderedProxy
--------------------------------------------------------------------------------


### `def compare(y: Long): Int`                                              ###

Result of comparing `this` with operand `that` .

Implement this method to determine how instances of A will be sorted.

Returns `x` where:

*  `x < 0` when `this < that`
*  `x == 0` when `this == that`
*  `x > 0` when `this > that`

* Definition Classes
  * OrderedProxy → Ordered

(defined at scala.runtime.OrderedProxy)


--------------------------------------------------------------------------------
              Deprecated Value Members From scala.runtime.RichLong
--------------------------------------------------------------------------------


### `def round: Long`                                                        ###

There is no reason to round a `Long` , but this method is provided to avoid
accidental conversion to `Int` through `Float` .

* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ This is an integer type; there is no reason to
    round it. Perhaps you meant to call this on a floating-point value?

(defined at scala.runtime.RichLong)


--------------------------------------------------------------------------------
               Instance Constructors From scala.runtime.RichLong
--------------------------------------------------------------------------------


### `new RichLong(self: Long)`                                               ###

(defined at scala.runtime.RichLong)


--------------------------------------------------------------------------------
                   Value Members From scala.runtime.RichLong
--------------------------------------------------------------------------------


### `def abs: Long`                                                          ###

Returns the absolute value of `this` .

* Definition Classes
  * RichLong → ScalaNumberProxy

(defined at scala.runtime.RichLong)


### `def byteValue(): Byte`                                                  ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def doubleValue(): Double`                                              ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def floatValue(): Float`                                                ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def intValue(): Int`                                                    ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def isValidByte: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Byte MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * RichLong → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def isValidChar: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Char MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * RichLong → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def isValidInt: Boolean`                                                ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Int MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * RichLong → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def isValidLong: Boolean`                                               ###

(defined at scala.runtime.RichLong)


### `def isValidShort: Boolean`                                              ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Short MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * RichLong → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def longValue(): Long`                                                  ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def max(that: Long): Long`                                              ###

Returns `this` if `this > that` or `that` otherwise.

* Definition Classes
  * RichLong → ScalaNumberProxy

(defined at scala.runtime.RichLong)


### `def min(that: Long): Long`                                              ###

Returns `this` if `this < that` or `that` otherwise.

* Definition Classes
  * RichLong → ScalaNumberProxy

(defined at scala.runtime.RichLong)


### `def num: LongIsIntegral.type`                                           ###

* Attributes
  * protected
* Definition Classes
  * RichLong → IntegralProxy → ScalaNumberProxy

(defined at scala.runtime.RichLong)


### `def ord: math.Ordering.Long.type`                                       ###

* Attributes
  * protected
* Definition Classes
  * RichLong → OrderedProxy

(defined at scala.runtime.RichLong)


### `val self: Long`                                                         ###

* Definition Classes
  * RichLong → Typed → Proxy

(defined at scala.runtime.RichLong)


### `def shortValue(): Short`                                                ###

* Definition Classes
  * RichLong → ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.RichLong)


### `def signum: Int`                                                        ###

Returns the signum of `this` .

* Definition Classes
  * RichLong → ScalaNumberProxy

(defined at scala.runtime.RichLong)


### `def toBinaryString: String`                                             ###

(defined at scala.runtime.RichLong)


### `def toHexString: String`                                                ###

(defined at scala.runtime.RichLong)


### `def toOctalString: String`                                              ###

(defined at scala.runtime.RichLong)


--------------------------------------------------------------------------------
               Value Members From scala.runtime.ScalaNumberProxy
--------------------------------------------------------------------------------


### `def underlying(): AnyRef`                                               ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


--------------------------------------------------------------------------------
             Value Members From scala.runtime.ScalaWholeNumberProxy
--------------------------------------------------------------------------------


### `def isWhole(): Boolean`                                                 ###

* returns
  * `true` if this number has no decimal component, `false` otherwise.

* Definition Classes
  * ScalaWholeNumberProxy → ScalaNumericAnyConversions
(defined at scala.runtime.ScalaWholeNumberProxy)
