
#                        scala.runtime.ScalaNumberProxy                        #

```
trait ScalaNumberProxy[T] extends ScalaNumericAnyConversions with Typed[T] with OrderedProxy[T]
```

Base classes for the Rich* wrappers of the primitive types. As with all classes
in scala.runtime.*, this is not a supported API.

* Source
  * [ScalaNumberProxy.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/runtime/ScalaNumberProxy.scala#L1)
* Version
  * 2.9
* Since
  * 2.9


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Any###
--------------------------------------------------------------------------------


### `final def ##(): Int`                                                    ###

Equivalent to `x.hashCode` except for boxed numeric types and `null` . For
numerics, it returns a hash value which is consistent with value equality: if
two value type instances compare as true, then ## will produce the same hash
value for each of them. For `null` returns a hashcode where `null.hashCode`
throws a `NullPointerException` .

* returns
  * a hash value consistent with ==

* Definition Classes
  * Any

(defined at scala.Any###)


--------------------------------------------------------------------------------
                    Concrete Value Members From scala.Proxy
--------------------------------------------------------------------------------


### `def equals(that: Any): Boolean`                                         ###

Compares the receiver object ( `this` ) with the argument object ( `that` ) for
equivalence.

Any implementation of this method should be an
[equivalence relation](http://en.wikipedia.org/wiki/Equivalence_relation) :

* It is reflexive: for any instance `x` of type `Any` , `x.equals(x)` should
   return `true` .
* It is symmetric: for any instances `x` and `y` of type `Any` , `x.equals(y)`
   should return `true` if and only if `y.equals(x)` returns `true` .
* It is transitive: for any instances `x` , `y` , and `z` of type `AnyRef` if
    `x.equals(y)` returns `true` and `y.equals(z)` returns `true` , then
    `x.equals(z)` should return `true` .

If you override this method, you should verify that your implementation remains
an equivalence relation. Additionally, when overriding this method it is usually
necessary to override `hashCode` to ensure that objects which are "equal" (
 `o1.equals(o2)` returns `true` ) hash to the same scala.Int. (
 `o1.hashCode.equals(o2.hashCode)` ).

* that
  * the object to compare against this object for equality.
* returns
  * `true` if the receiver object is equivalent to the argument; `false`
    otherwise.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def hashCode(): Int`                                                    ###

Calculate a hash code value for the object.

The default hashing algorithm is platform dependent.

Note that it is allowed for two objects to have identical hash codes (
 `o1.hashCode.equals(o2.hashCode)` ) yet not be equal ( `o1.equals(o2)` returns
 `false` ). A degenerate implementation could always return `0` . However, it is
required that if two objects are equal ( `o1.equals(o2)` returns `true` ) that
they have identical hash codes ( `o1.hashCode.equals(o2.hashCode)` ). Therefore,
when overriding this method, be sure to verify that the behavior is consistent
with the `equals` method.

* returns
  * the hash code value for this object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


### `def toString(): String`                                                 ###

Returns a string representation of the object.

The default representation is platform dependent.

* returns
  * a string representation of the object.

* Definition Classes
  * Proxy → Any

(defined at scala.Proxy)


--------------------------------------------------------------------------------
                 Abstract Value Members From scala.Proxy.Typed
--------------------------------------------------------------------------------


### `abstract def self: T`                                                   ###

* Definition Classes
  * Typed → Proxy

(defined at scala.Proxy.Typed)


--------------------------------------------------------------------------------
                 Concrete Value Members From scala.math.Ordered
--------------------------------------------------------------------------------


### `def <(that: T): Boolean`                                                ###

Returns true if `this` is less than `that`

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def <=(that: T): Boolean`                                               ###

Returns true if `this` is less than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >(that: T): Boolean`                                                ###

Returns true if `this` is greater than `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def >=(that: T): Boolean`                                               ###

Returns true if `this` is greater than or equal to `that` .

* Definition Classes
  * Ordered

(defined at scala.math.Ordered)


### `def compareTo(that: T): Int`                                            ###

Result of comparing `this` with operand `that` .

* Definition Classes
  * Ordered → Comparable

(defined at scala.math.Ordered)


--------------------------------------------------------------------------------
       Abstract Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `abstract def isWhole(): Boolean`                                        ###

* returns
  * `true` if this number has no decimal component, `false` otherwise.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
       Concrete Value Members From scala.math.ScalaNumericAnyConversions
--------------------------------------------------------------------------------


### `def isValidByte: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Byte MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidChar: Boolean`                                               ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Char MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidInt: Boolean`                                                ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Int MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def isValidShort: Boolean`                                              ###

Returns `true` iff this has a zero fractional part, and is within the range of
scala.Short MinValue and MaxValue; otherwise returns `false` .

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toByte: Byte`                                                       ###

Returns the value of this as a scala.Byte. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toChar: Char`                                                       ###

Returns the value of this as a scala.Char. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toDouble: Double`                                                   ###

Returns the value of this as a scala.Double. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toFloat: Float`                                                     ###

Returns the value of this as a scala.Float. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toInt: Int`                                                         ###

Returns the value of this as an scala.Int. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toLong: Long`                                                       ###

Returns the value of this as a scala.Long. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def toShort: Short`                                                     ###

Returns the value of this as a scala.Short. This may involve rounding or
truncation.

* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveEquals(x: Any): Boolean`                            ###

Should only be called after all known non-primitive types have been excluded.
This method won't dispatch anywhere else after checking against the primitives
to avoid infinite recursion between equals and this on unknown "Number"
variants.

Additionally, this should only be called if the numeric type is happy to be
converted to Long, Float, and Double. If for instance a BigInt much larger than
the Long range is sent here, it will claim equality with whatever Long is left
in its lower 64 bits. Or a BigDecimal with more precision than Double can hold:
same thing. There's no way given the interface available here to prevent this
error.

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


### `def unifiedPrimitiveHashcode(): Int`                                    ###

* Attributes
  * protected
* Definition Classes
  * ScalaNumericAnyConversions

(defined at scala.math.ScalaNumericAnyConversions)


--------------------------------------------------------------------------------
             Abstract Value Members From scala.runtime.OrderedProxy
--------------------------------------------------------------------------------


### `abstract def ord: Ordering[T]`                                          ###

* Attributes
  * protected
* Definition Classes
  * OrderedProxy

(defined at scala.runtime.OrderedProxy)


--------------------------------------------------------------------------------
             Concrete Value Members From scala.runtime.OrderedProxy
--------------------------------------------------------------------------------


### `def compare(y: T): Int`                                                 ###

Result of comparing `this` with operand `that` .

Implement this method to determine how instances of A will be sorted.

Returns `x` where:

*  `x < 0` when `this < that`
*  `x == 0` when `this == that`
*  `x > 0` when `this > that`

* Definition Classes
  * OrderedProxy → Ordered

(defined at scala.runtime.OrderedProxy)


--------------------------------------------------------------------------------
           Abstract Value Members From scala.runtime.ScalaNumberProxy
--------------------------------------------------------------------------------


### `implicit abstract def num: Numeric[T]`                                  ###

* Attributes
  * protected

(defined at scala.runtime.ScalaNumberProxy)


--------------------------------------------------------------------------------
           Concrete Value Members From scala.runtime.ScalaNumberProxy
--------------------------------------------------------------------------------


### `def abs: T`                                                             ###

Returns the absolute value of `this` .

(defined at scala.runtime.ScalaNumberProxy)


### `def byteValue(): Byte`                                                  ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def doubleValue(): Double`                                              ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def floatValue(): Float`                                                ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def intValue(): Int`                                                    ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def longValue(): Long`                                                  ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def max(that: T): T`                                                    ###

Returns `this` if `this > that` or `that` otherwise.

(defined at scala.runtime.ScalaNumberProxy)


### `def min(that: T): T`                                                    ###

Returns `this` if `this < that` or `that` otherwise.

(defined at scala.runtime.ScalaNumberProxy)


### `def shortValue(): Short`                                                ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions

(defined at scala.runtime.ScalaNumberProxy)


### `def signum: Int`                                                        ###

Returns the signum of `this` .

(defined at scala.runtime.ScalaNumberProxy)


### `def underlying(): AnyRef`                                               ###

* Definition Classes
  * ScalaNumberProxy → ScalaNumericAnyConversions
(defined at scala.runtime.ScalaNumberProxy)
