
#                                scala.sys.Prop                                #

```
trait Prop[+T] extends AnyRef
```

A lightweight interface wrapping a property contained in some unspecified map.
Generally it'll be the system properties but this is not a requirement.

See `scala.sys.SystemProperties` for an example usage.

* Source
  * [Prop.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/sys/Prop.scala#L1)
* Version
  * 2.9
* Since
  * 2.9


--------------------------------------------------------------------------------
                   Abstract Value Members From scala.sys.Prop
--------------------------------------------------------------------------------


### `abstract def clear(): Unit`                                             ###

Removes the property from the underlying map.

(defined at scala.sys.Prop)


### `abstract def get: String`                                               ###

Gets the current string value if any. Will not return null: use `isSet` to test
for existence.

* returns
  * the current string value if any, else the empty string

(defined at scala.sys.Prop)


### `abstract def isSet: Boolean`                                            ###

True if the key exists in the properties map. Note that this is not sufficient
for a Boolean property to be considered true.

* returns
  * whether the map contains the key

(defined at scala.sys.Prop)


### `abstract def key: String`                                               ###

The full name of the property, e.g., "java.awt.headless".

(defined at scala.sys.Prop)


### `abstract def option: Option[T]`                                         ###

Some(value) if the property is set, None otherwise.

(defined at scala.sys.Prop)


### `abstract def set(newValue: String): String`                             ###

Sets the property.

* newValue
  * the new string value
* returns
  * the old value, or null if it was unset.

(defined at scala.sys.Prop)


### `abstract def setValue[T1 >: T](value: T1): T`                           ###

Sets the property with a value of the represented type.

(defined at scala.sys.Prop)


### `abstract def value: T`                                                  ###

If the key exists in the properties map, converts the value to type `T` using
valueFn. As yet no validation is performed: it will throw an exception on a
failed conversion.

* returns
  * the converted value, or `zero` if not in the map

(defined at scala.sys.Prop)


### `abstract def zero: T`                                                   ###

A value of type `T` for use when the property is unset. The default
implementation delivers null for reference types and 0/0.0/false for
non-reference types.

* Attributes
  * protected
(defined at scala.sys.Prop)
