
#                              scala.util.Sorting                              #

```
object Sorting
```

The Sorting object provides functions that can sort various kinds of objects.
You can provide a comparison function, or you can request a sort of items that
are viewable as scala.math.Ordered. Some sorts that operate directly on a subset
of value types are also provided. These implementations are derived from those
in the Sun JDK.

Note that stability doesn't matter for value types, so use the `quickSort`
variants for those. `stableSort` is intended to be used with objects when the
prior ordering should be preserved, where possible.

* Source
  * [Sorting.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/util/Sorting.scala#L1)
* Version
  * 1.0


--------------------------------------------------------------------------------
                     Value Members From scala.util.Sorting
--------------------------------------------------------------------------------


### `def quickSort(a: Array[Double]): Unit`                                  ###

Quickly sort an array of Doubles.

(defined at scala.util.Sorting)


### `def quickSort(a: Array[Float]): Unit`                                   ###

Quickly sort an array of Floats.

(defined at scala.util.Sorting)


### `def quickSort(a: Array[Int]): Unit`                                     ###

Quickly sort an array of Ints.

(defined at scala.util.Sorting)


### `def quickSort[K](a: Array[K])(implicit arg0: math.Ordering[K]): Unit`   ###

Quickly sort an array of items with an implicit Ordering.

(defined at scala.util.Sorting)


### `def stableSort[K, M](a: Seq[K], f: (K) ⇒ M)(implicit arg0: ClassTag[K], arg1: math.Ordering[M]): Array[K]` ###

Stably sorts a sequence of items given an extraction function that will return
an ordered key from an item.

* a
  * the sequence to be sorted.
* f
  * the comparison function.
* returns
  * the sorted sequence of items.

(defined at scala.util.Sorting)


### `def stableSort[K](a: Array[K])(implicit arg0: ClassTag[K], arg1: math.Ordering[K]): Unit` ###

Sort an array of K where K is Ordered, preserving the existing order where the
values are equal.

(defined at scala.util.Sorting)


### `def stableSort[K](a: Array[K], f: (K, K) ⇒ Boolean)(implicit arg0: ClassTag[K]): Unit` ###

Sorts an array of `K` given an ordering function `f` . `f` should return `true`
iff its first parameter is strictly less than its second parameter.

(defined at scala.util.Sorting)


### `def stableSort[K](a: Seq[K])(implicit arg0: ClassTag[K], arg1: math.Ordering[K]): Array[K]` ###

Sorts an arbitrary sequence of items that are viewable as ordered.

(defined at scala.util.Sorting)


### `def stableSort[K](a: Seq[K], f: (K, K) ⇒ Boolean)(implicit arg0: ClassTag[K]): Array[K]` ###

Sorts an arbitrary sequence into an array, given a comparison function that
should return `true` iff parameter one is strictly less than parameter two.

* a
  * the sequence to be sorted.
* f
  * the comparison function.
* returns
  * the sorted sequence of items.
(defined at scala.util.Sorting)
