
#                     scala.util.control.ControlThrowable                     #

```
trait ControlThrowable extends Throwable with NoStackTrace
```

A marker trait indicating that the `Throwable` it is mixed into is intended for
flow control.

Note that `Throwable` subclasses which extend this trait may extend any other
 `Throwable` subclass (eg. `RuntimeException` ) and are not required to extend
 `Throwable` directly.

Instances of `Throwable` subclasses marked in this way should not normally be
caught. Where catch-all behaviour is required `ControlThrowable` should be
propagated, for example:

```scala
import scala.util.control.ControlThrowable

try {
  // Body might throw arbitrarily
} catch {
  case c: ControlThrowable => throw c // propagate
  case t: Exception        => log(t)  // log and suppress
}
```

* Source
  * [ControlThrowable.scala](https://github.com/scala/scala/tree/v2.11.5/src/library/scala/util/control/ControlThrowable.scala#L1)


--------------------------------------------------------------------------------
                     Value Members From java.lang.Throwable
--------------------------------------------------------------------------------


### `def getCause(): java.lang.Throwable`                                    ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def getLocalizedMessage(): String`                                      ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def getMessage(): String`                                               ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def getStackTrace(): Array[StackTraceElement]`                          ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def initCause(arg0: java.lang.Throwable): java.lang.Throwable`          ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def printStackTrace(): Unit`                                            ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def printStackTrace(arg0: PrintStream): Unit`                           ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def printStackTrace(arg0: PrintWriter): Unit`                           ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def setStackTrace(arg0: Array[StackTraceElement]): Unit`                ###

* Definition Classes
  * Throwable

(defined at java.lang.Throwable)


### `def toString(): String`                                                 ###

Creates a String representation of this object. The default representation is
platform dependent. On the java platform it is the concatenation of the class
name, "@", and the object's hashcode in hexadecimal.

* returns
  * a String representation of the object.

* Definition Classes
  * Throwable → AnyRef → Any

(defined at java.lang.Throwable)


--------------------------------------------------------------------------------
               Value Members From scala.util.control.NoStackTrace
--------------------------------------------------------------------------------


### `def fillInStackTrace(): Throwable`                                      ###

* Definition Classes
  * NoStackTrace → Throwable

(defined at scala.util.control.NoStackTrace)


--------------------------------------------------------------------------------
       Deprecated Value Members From Implicit scala.Predef.RichException
--------------------------------------------------------------------------------


### `def getStackTraceString: String`                                        ###

* Implicit information
  * This member is added by an implicit conversion from ControlThrowable to
    RichException performed by method RichException in scala.Predef.
* Definition Classes
  * RichException
* Annotations
  * @ deprecated
* Deprecated
  * _(Since version 2.11.0)_ Use Throwable#getStackTrace
(added by implicit convertion: scala.Predef.RichException)
